@@ -5,12 +5,12 @@
 @author  Daniel Krajzewicz
 @author  Lena Kalleske
 @date    2008-07-21
-@version $Id: vehicleControl.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: vehicleControl.py 20433 2016-04-13 08:00:14Z behrisch $
 
 Control the CityMobil parking lot via TraCI.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2008-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2008-2016 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -18,26 +18,37 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
-import subprocess, random, sys, os
+from __future__ import absolute_import
+from __future__ import print_function
+import subprocess
+import random
+import sys
+import os
 from optparse import OptionParser
 
-from constants import * # sys.path is modified here
+from constants import *  # sys.path is modified here
 
 import traci
 import traci.constants as tc
 
 import statistics
 
+
 class Manager:
+
     def personArrived(self, vehicleID, edge, target):
         raise NotImplementedError
+
     def cyberCarArrived(self, vehicleID, edge):
         raise NotImplementedError
+
     def cyberCarBroken(self, vehicleID, edge):
         pass
+
     def setNewTargets(self):
         pass
 
+
 class Status:
 
     def __init__(self, edge, pos):
@@ -52,9 +63,10 @@ class Status:
     def __repr__(self):
         return "%s,%s" % (self.edge, self.pos)
 
+
 class Setting:
     step = 0
-    manager = None 
+    manager = None
     verbose = False
     cyber = False
 
@@ -64,6 +76,7 @@ vehicleStatus = {}
 persons = {}
 waiting = {}
 
+
 def init(manager, forTest=False):
     optParser = OptionParser()
     optParser.add_option("-v", "--verbose", action="store_true", dest="verbose",
@@ -83,7 +96,8 @@ def init(manager, forTest=False):
     sumoConfig = "%s%02i.sumocfg" % (PREFIX, options.demand)
     if options.cyber:
         sumoConfig = "%s%02i_cyber.sumocfg" % (PREFIX, options.demand)
-    sumoProcess = subprocess.Popen([sumoExe, sumoConfig], stdout=sys.stdout, stderr=sys.stderr)
+    sumoProcess = subprocess.Popen(
+        [sumoExe, sumoConfig], stdout=sys.stdout, stderr=sys.stderr)
     traci.init(PORT)
     traci.simulation.subscribe()
     setting.manager = manager
@@ -98,17 +112,21 @@ def init(manager, forTest=False):
         traci.close()
         sumoProcess.wait()
 
+
 def getCapacity():
     if setting.cyber:
         return CYBER_CAPACITY
     return BUS_CAPACITY
 
+
 def getStep():
     return setting.step
 
+
 def getPosition(vehicleID):
     return vehicleStatus[vehicleID].edge
 
+
 def stopAt(vehicleID, edge, pos=None):
     if pos == None:
         pos = STOP_POS
@@ -116,13 +134,14 @@ def stopAt(vehicleID, edge, pos=None):
             pos = 90.
     traci.vehicle.changeTarget(vehicleID, edge)
     if setting.verbose:
-        print "stopAt", vehicleID, edge, pos
+        print("stopAt", vehicleID, edge, pos)
 #        print vehicleStatus[vehicleID]
 #        print traci.vehicle.getRoute(vehicleID)
     traci.vehicle.setStop(vehicleID, edge, pos)
     vehicleStatus[vehicleID].target = edge
     vehicleStatus[vehicleID].targetPos = pos
 
+
 def leaveStop(vehicleID, newTarget=None, delay=0.):
     v = vehicleStatus[vehicleID]
     if newTarget:
@@ -132,6 +151,7 @@ def leaveStop(vehicleID, newTarget=None, delay=0.):
     v.targetPos = None
     v.parking = False
 
+
 def _rerouteCar(vehicleID):
     slotEdge = ""
     for rowIdx in range(DOUBLE_ROWS):
@@ -140,20 +160,23 @@ def _rerouteCar(vehicleID):
                 slotEdge = "slot%s-%s%s" % (rowIdx, idx, dir)
                 if not slotEdge in occupancy:
                     occupancy[slotEdge] = vehicleID
-                    stopAt(vehicleID, slotEdge, SLOT_LENGTH-5.)
+                    stopAt(vehicleID, slotEdge, SLOT_LENGTH - 5.)
                     return
 
+
 def _reroutePersons(edge):
     if edge in persons:
         for person in persons[edge]:
             if not vehicleStatus[person].slot:
                 row = int(edge[4])
-                targetEdge = "footmain%sto%s" % (row, row+1)
-                traci.vehicle.setStop(person, edge.replace("slot", "-foot"), 1., 0, 0.)
+                targetEdge = "footmain%sto%s" % (row, row + 1)
+                traci.vehicle.setStop(
+                    person, edge.replace("slot", "-foot"), 1., 0, 0.)
                 stopAt(person, targetEdge)
                 vehicleStatus[person].parking = False
                 vehicleStatus[person].slot = edge
 
+
 def _checkInitialPositions(vehicleID, edge, pos):
     if vehicleID in vehicleStatus:
         vehicleStatus[vehicleID].edge = edge
@@ -167,26 +190,29 @@ def _checkInitialPositions(vehicleID, edge, pos):
         elif edge == "footfairin":
             stopAt(vehicleID, "footmainout")
         elif "foot" in edge:
-            traci.vehicle.setStop(vehicleID, "-"+edge)
+            traci.vehicle.setStop(vehicleID, "-" + edge)
             parkEdge = edge.replace("foot", "slot")
             if not parkEdge in persons:
                 persons[parkEdge] = []
             persons[parkEdge].append(vehicleID)
             vehicleStatus[vehicleID].parking = True
         elif edge.startswith("slot"):
-            stopAt(vehicleID, edge, SLOT_LENGTH-5.)
+            stopAt(vehicleID, edge, SLOT_LENGTH - 5.)
             occupancy[edge] = vehicleID
     _reroutePersons(edge)
 
+
 def doStep():
     setting.step += 1
     if setting.verbose:
-        print "step", setting.step
+        print("step", setting.step)
     traci.simulationStep()
     moveNodes = []
     for veh, subs in traci.vehicle.getSubscriptionResults().iteritems():
-        moveNodes.append((veh, subs[tc.VAR_ROAD_ID], subs[tc.VAR_LANEPOSITION]))
-    departed = traci.simulation.getSubscriptionResults()[tc.VAR_DEPARTED_VEHICLES_IDS]
+        moveNodes.append(
+            (veh, subs[tc.VAR_ROAD_ID], subs[tc.VAR_LANEPOSITION]))
+    departed = traci.simulation.getSubscriptionResults(
+    )[tc.VAR_DEPARTED_VEHICLES_IDS]
     for v in departed:
         traci.vehicle.subscribe(v)
         subs = traci.vehicle.getSubscriptionResults(v)
@@ -200,7 +226,7 @@ def doStep():
                 target = "footmainout"
                 if edge == "footmainout":
                     row = random.randrange(0, DOUBLE_ROWS)
-                    target = "footmain%sto%s" % (row, row+1)
+                    target = "footmain%sto%s" % (row, row + 1)
                 statistics.personArrived(vehicleID, edge, target, setting.step)
                 setting.manager.personArrived(vehicleID, edge, target)
             if edge.startswith("cyber"):
@@ -208,13 +234,13 @@ def doStep():
                     vehicle.delay -= 1
                 elif setting.breakstep and setting.step >= setting.breakstep and edge != "cyberin":
                     if setting.verbose:
-                        print "broken", vehicleID, edge
+                        print("broken", vehicleID, edge)
                     setting.breakstep = None
                     setting.manager.cyberCarBroken(vehicleID, edge)
                     vehicle.delay = BREAK_DELAY
                 else:
                     if setting.verbose:
-                        print "arrived", vehicleID, edge
+                        print("arrived", vehicleID, edge)
                     vehicle.parking = True
                     setting.manager.cyberCarArrived(vehicleID, edge)
     setting.manager.setNewTargets()
