@@ -6,12 +6,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Jul 2010
-/// @version $Id: activitygen_main.cpp 18095 2015-03-17 09:39:00Z behrisch $
+/// @version $Id: activitygen_main.cpp 20433 2016-04-13 08:00:14Z behrisch $
 ///
 // Main object of the ActivityGen application
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -44,7 +44,6 @@
 #include <router/RONet.h>
 #include <router/ROLoader.h>
 #include <router/RONetHandler.h>
-#include <duarouter/RODUAEdgeBuilder.h>
 #include <utils/options/OptionsIO.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/common/ToString.h>
@@ -102,7 +101,7 @@ main(int argc, char* argv[]) {
     // give some application descriptions
     oc.setApplicationDescription(
         "Generates routes of persons throughout a day for the microscopic road traffic simulation SUMO.");
-    oc.setApplicationName("activitygen", "SUMO activitygen Version " + getBuildName(VERSION_STRING));
+    oc.setApplicationName("activitygen", "SUMO activitygen Version " VERSION_STRING);
     oc.addCopyrightNotice("Copyright (C) 2010-2012 Technische Universitaet Muenchen");
     int ret = 0;
     RONet* net = 0;
@@ -110,7 +109,8 @@ main(int argc, char* argv[]) {
         // Initialise subsystems and process options
         XMLSubSys::init();
         AGFrame::fillOptions();
-        OptionsIO::getOptions(true, argc, argv);
+        OptionsIO::setArgs(argc, argv);
+        OptionsIO::getOptions();
         if (oc.processMetaOptions(argc < 2)) {
             SystemFrame::close();
             return 0;
