@@ -5,13 +5,13 @@
 /// @author  Walter Bamberger
 /// @author  Michael Behrisch
 /// @date    July 2010
-/// @version $Id: AGCity.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: AGCity.h 20433 2016-04-13 08:00:14Z behrisch $
 ///
 // City class that contains all other objects of the city: in particular
 // streets, households, bus lines, work positions and schools
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2010-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2010-2016 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -86,7 +86,7 @@ public:
     const AGStreet& getRandomStreet();
 
     AGDataAndStatistics& statData;
-    std::vector<AGStreet> streets;
+    std::vector<AGStreet*> streets;
     std::vector<AGWorkPosition> workPositions;
     std::list<AGSchool> schools;
     std::list<AGBusLine> busLines;
