@@ -5,7 +5,7 @@
 /// @author  Michael Behrisch
 /// @author  Andreas Gaubatz
 /// @date    Sept 2002
-/// @version $Id: GUIApplicationWindow.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GUIApplicationWindow.cpp 21206 2016-07-20 08:08:35Z behrisch $
 ///
 // The main window of the SUMO-gui.
 /****************************************************************************/
@@ -754,7 +754,7 @@ GUIApplicationWindow::onCmdNetedit(FXObject*, FXSelector, void*) {
     const GUISUMOAbstractView* const v = static_cast<GUIGlChildWindow*>(mySubWindows[0])->getView();
     reg.writeIntEntry("viewport", "x", v->getChanger().getXPos());
     reg.writeIntEntry("viewport", "y", v->getChanger().getYPos());
-    reg.writeIntEntry("viewport", "z", v->getChanger().getZoom());
+    reg.writeIntEntry("viewport", "z", v->getChanger().getZPos());
     reg.write();
     std::string netedit = "netedit";
     const char* sumoPath = getenv("SUMO_HOME");
@@ -1273,7 +1273,7 @@ GUIApplicationWindow::handleEvent_SimulationLoaded(GUIEvent* e) {
                     }
                     std::string settingsName = settings.addSettings(view);
                     view->addDecals(settings.getDecals());
-                    settings.setViewport(view);
+                    settings.applyViewport(view);
                     settings.setSnapshots(view);
                     if (settings.getDelay() > 0) {
                         mySimDelayTarget->setValue(settings.getDelay());
@@ -1319,8 +1319,8 @@ void
 GUIApplicationWindow::handleEvent_SimulationStep(GUIEvent*) {
     updateChildren();
     updateTimeLCD(myRunThread->getNet().getCurrentTimeStep());
-    const unsigned int running = myRunThread->getNet().getVehicleControl().getRunningVehicleNo();
-    const unsigned int backlog = myRunThread->getNet().getInsertionControl().getWaitingVehicleNo();
+    const int running = myRunThread->getNet().getVehicleControl().getRunningVehicleNo();
+    const int backlog = myRunThread->getNet().getInsertionControl().getWaitingVehicleNo();
     if (backlog > running) {
         if (myStatButtons.front()->getIcon() == GUIIconSubSys::getIcon(ICON_GREENVEHICLE)) {
             myStatButtons.front()->setIcon(GUIIconSubSys::getIcon(ICON_YELLOWVEHICLE));
@@ -1422,7 +1422,7 @@ GUIApplicationWindow::checkGamingEvents() {
         }
     }
     if (myCollisionSounds.getOverallProb() > 0) {
-        unsigned int collisions = MSNet::getInstance()->getVehicleControl().getCollisionCount();
+        int collisions = MSNet::getInstance()->getVehicleControl().getCollisionCount();
         if (myPreviousCollisionNumber != collisions) {
             const std::string cmd = myCollisionSounds.get(&myGamingRNG);
             if (cmd != "") {
@@ -1469,11 +1469,22 @@ GUIApplicationWindow::openNewView(GUISUMOViewParent::ViewType vt) {
         myStatusbar->getStatusLine()->setText("No simulation loaded!");
         return 0;
     }
+    GUISUMOAbstractView* oldView = 0;
+    if (myMDIClient->numChildren() > 0) {
+        GUISUMOViewParent* w = dynamic_cast<GUISUMOViewParent*>(myMDIClient->getActiveChild());
+        if (w != 0) {
+            oldView = w->getView();
+        }
+    }
     std::string caption = "View #" + toString(myViewNumber++);
     FXuint opts = MDI_TRACKING;
     GUISUMOViewParent* w = new GUISUMOViewParent(myMDIClient, myMDIMenu, FXString(caption.c_str()),
             this, GUIIconSubSys::getIcon(ICON_APP), opts, 10, 10, 300, 200);
     GUISUMOAbstractView* v = w->init(getBuildGLCanvas(), myRunThread->getNet(), vt);
+    if (oldView != 0) {
+        // copy viewport
+        oldView->copyViewportTo(v);
+    }
     w->create();
     if (myMDIClient->numChildren() == 1) {
         w->maximize();
@@ -1481,6 +1492,7 @@ GUIApplicationWindow::openNewView(GUISUMOViewParent::ViewType vt) {
         myMDIClient->vertical(true);
     }
     myMDIClient->setActiveChild(w);
+
     return v;
 }
 
@@ -1507,11 +1519,11 @@ GUIApplicationWindow::closeAllWindows() {
         }
     }
     // remove trackers and other external windows
-    size_t i;
-    for (i = 0; i < mySubWindows.size(); ++i) {
+    int i;
+    for (i = 0; i < (int)mySubWindows.size(); ++i) {
         mySubWindows[i]->destroy();
     }
-    for (i = 0; i < myTrackerWindows.size(); ++i) {
+    for (i = 0; i < (int)myTrackerWindows.size(); ++i) {
         myTrackerWindows[i]->destroy();
     }
     // delete the simulation
