@@ -4,7 +4,7 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUILoadThread.cpp 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: GUILoadThread.cpp 21010 2016-06-20 13:32:41Z behrisch $
 ///
 // Class describing the thread that performs the loading of a simulation
 /****************************************************************************/
@@ -126,6 +126,9 @@ GUILoadThread::run() {
                 myFile = oc.getString("net-file");
                 myLoadNet = true;
             }
+            myEventQue.add(new GUIEvent_Message("Loading '" + myFile + "'."));
+            myEventThrow.signal();
+            myParent->addRecentFile(FXPath::absolute(myFile.c_str()), myLoadNet);
         }
         myTitle = myFile;
         // within gui-based applications, nothing is reported to the console
@@ -139,12 +142,13 @@ GUILoadThread::run() {
             oc.set("verbose", "true");
         }
         MsgHandler::initOutputOptions();
-        XMLSubSys::setValidation(oc.getString("xml-validation"), oc.getString("xml-validation.net"));
-        GUIGlobals::gRunAfterLoad = oc.getBool("start");
-        GUIGlobals::gQuitOnEnd = oc.getBool("quit-on-end");
         if (!MSFrame::checkOptions()) {
             throw ProcessError();
         }
+        XMLSubSys::setValidation(oc.getString("xml-validation"), oc.getString("xml-validation.net"));
+        GUIGlobals::gRunAfterLoad = oc.getBool("start");
+        GUIGlobals::gQuitOnEnd = oc.getBool("quit-on-end");
+        GUIGlobals::gDemoAutoReload = oc.getBool("demo");
     } catch (ProcessError& e) {
         if (std::string(e.what()) != std::string("Process Error") && std::string(e.what()) != std::string("")) {
             WRITE_ERROR(e.what());
