@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Jan 2004
-/// @version $Id: ROJTRTurnDefLoader.cpp 18095 2015-03-17 09:39:00Z behrisch $
+/// @version $Id: ROJTRTurnDefLoader.cpp 20433 2016-04-13 08:00:14Z behrisch $
 ///
 // Loader for the of turning percentages and source/sink definitions
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -84,7 +84,7 @@ ROJTRTurnDefLoader::myStartElement(int element,
                     if (edge == 0) {
                         throw ProcessError("The edge '" + id + "' declared as a sink is not known.");
                     }
-                    edge->setType(ROEdge::ET_SINK);
+                    edge->setFunc(ROEdge::ET_SINK);
                 }
             }
             break;
@@ -98,7 +98,7 @@ ROJTRTurnDefLoader::myStartElement(int element,
                     if (edge == 0) {
                         throw ProcessError("The edge '" + id + "' declared as a source is not known.");
                     }
-                    edge->setType(ROEdge::ET_SOURCE);
+                    edge->setFunc(ROEdge::ET_SOURCE);
                 }
             }
             break;
