@@ -6,12 +6,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    2003-05-21
-/// @version $Id: MSMoveReminder.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MSMoveReminder.h 20433 2016-04-13 08:00:14Z behrisch $
 ///
 // Something on a lane to be noticed about vehicle movement
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2003-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2003-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -181,10 +181,9 @@ public:
     }
 
 
-#ifdef HAVE_INTERNAL
     void updateDetector(SUMOVehicle& veh, SUMOReal entryPos, SUMOReal leavePos,
-                        SUMOTime entryTime, SUMOTime currentTime, SUMOTime leaveTime);
-#endif
+                        SUMOTime entryTime, SUMOTime currentTime, SUMOTime leaveTime,
+                        bool cleanUp);
 
     /// @}
 
@@ -215,16 +214,18 @@ public:
         return myDescription;
     }
 
+protected:
+    void removeFromVehicleUpdateValues(SUMOVehicle& veh);
 
 protected:
+
     /// @brief Lane on which the reminder works
     MSLane* const myLane;
     /// @brief a description of this moveReminder
     std::string myDescription;
 
-#ifdef HAVE_INTERNAL
+private:
     std::map<SUMOVehicle*, std::pair<SUMOTime, SUMOReal> > myLastVehicleUpdateValues;
-#endif
 
 
 private:
