@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: MSRouteHandler.h 18756 2015-08-31 19:16:33Z behrisch $
+/// @version $Id: MSRouteHandler.h 20462 2016-04-15 12:20:52Z luecken $
 ///
 // Parser and container for routes during their loading
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -145,7 +145,7 @@ protected:
 
     ///@ brief parse depart- and arrival positions of a walk
     void parseWalkPositions(const SUMOSAXAttributes& attrs, const std::string& personID,
-                            const MSEdge* fromEdge, const MSEdge* toEdge,
+                            const MSEdge* fromEdge, const MSEdge*& toEdge,
                             SUMOReal& departPos, SUMOReal& arrivalPos, MSStoppingPlace*& bs, bool& ok);
     SUMOReal parseWalkPos(SumoXMLAttr attr, const std::string& id, const MSEdge* edge, const std::string& val);
 
@@ -178,6 +178,9 @@ protected:
     static MTRand myParsingRNG;
 
 private:
+    /// @brief delete already created MSTransportablePlans if error occurs before handing over responsibility to a MSTransportable.
+    void deleteActivePlans();
+
     /// @brief Invalidated copy constructor
     MSRouteHandler(const MSRouteHandler& s);
 
