@@ -4,7 +4,7 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Mon, 12 Mar 2001
-/// @version $Id: MSVehicleContainer.cpp 20687 2016-05-10 11:27:00Z behrisch $
+/// @version $Id: MSVehicleContainer.cpp 21182 2016-07-18 06:46:01Z behrisch $
 ///
 // vehicles sorted by their departures
 /****************************************************************************/
@@ -73,7 +73,7 @@ MSVehicleContainer::DepartFinder::operator()
 /* -------------------------------------------------------------------------
  * methods from MSVehicleContainer
  * ----------------------------------------------------------------------- */
-MSVehicleContainer::MSVehicleContainer(size_t capacity)
+MSVehicleContainer::MSVehicleContainer(int capacity)
     : currentSize(0), array(capacity + 1, VehicleDepartureVector()) {}
 
 
@@ -145,10 +145,10 @@ MSVehicleContainer::addReplacing(const VehicleDepartureVector& x) {
     // Percolate up
     int hole = ++currentSize;
     for (; hole > 1 && (x.first < array[ hole / 2 ].first); hole /= 2) {
-        assert(array.size() > (size_t) hole);
+        assert(array.size() > (int) hole);
         array[ hole ] = array[ hole / 2 ];
     }
-    assert(array.size() > (size_t) hole);
+    assert(array.size() > (int) hole);
     array[ hole ] = x;
 }
 
@@ -208,7 +208,7 @@ MSVehicleContainer::isFull() const {
 void
 MSVehicleContainer::percolateDown(int hole) {
     int child;
-    assert(array.size() > (size_t)hole);
+    assert(array.size() > (int)hole);
     VehicleDepartureVector tmp = array[ hole ];
 
     for (; hole * 2 <= currentSize; hole = child) {
@@ -217,18 +217,18 @@ MSVehicleContainer::percolateDown(int hole) {
             child++;
         }
         if ((array[ child ].first < tmp.first)) {
-            assert(array.size() > (size_t) hole);
+            assert(array.size() > (int) hole);
             array[ hole ] = array[ child ];
         } else {
             break;
         }
     }
-    assert(array.size() > (size_t) hole);
+    assert(array.size() > (int) hole);
     array[ hole ] = tmp;
 }
 
 
-size_t
+int
 MSVehicleContainer::size() const {
     return currentSize;
 }
