@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    14.08.2013
-/// @version $Id: MSDevice_BTreceiver.cpp 17262 2014-11-04 20:41:44Z behrisch $
+/// @version $Id: MSDevice_BTreceiver.cpp 20433 2016-04-13 08:00:14Z behrisch $
 ///
 // A BT sender
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2013-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2013-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -34,7 +34,6 @@
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/vehicle/SUMOVehicle.h>
 #include <utils/geom/Position.h>
-#include <utils/geom/Line.h>
 #include <utils/geom/GeomHelper.h>
 #include <microsim/MSNet.h>
 #include <microsim/MSLane.h>
@@ -194,8 +193,7 @@ MSDevice_BTreceiver::BTreceiverUpdate::updateVisibility(MSDevice_BTreceiver::Veh
     if (!receiver.amOnNet || !sender.amOnNet) {
         // at least one of the vehicles has left the simulation area for any reason
         if (receiver.currentlySeen.find(sender.getID()) != receiver.currentlySeen.end()) {
-            leaveRange(receiver.currentlySeen, receiver.seen, receiverData.position, receiverData.speed, receiverData.laneID, receiverData.lanePos,
-                       sender.getID(), senderData.position, senderData.speed, senderData.laneID, senderData.lanePos, 0);
+            leaveRange(receiver, receiverData, sender, senderData, 0);
         }
     }
 
@@ -208,51 +206,52 @@ MSDevice_BTreceiver::BTreceiverUpdate::updateVisibility(MSDevice_BTreceiver::Veh
     const Position translatedSender = senderData.position - receiverDelta;
     // find crossing points
     std::vector<SUMOReal> intersections;
-    GeomHelper::FindLineCircleIntersections(oldReceiverPosition, receiver.range, oldSenderPosition, translatedSender, intersections);
+    GeomHelper::findLineCircleIntersections(oldReceiverPosition, receiver.range, oldSenderPosition, translatedSender, intersections);
     switch (intersections.size()) {
         case 0:
             // no intersections -> other vehicle either stays within or beyond range
             if (receiver.amOnNet && sender.amOnNet && receiverData.position.distanceTo(senderData.position) < receiver.range) {
                 if (receiver.currentlySeen.find(sender.getID()) == receiver.currentlySeen.end()) {
-                    enterRange(0., receiverData.position, receiverData.speed, receiverData.laneID, receiverData.lanePos,
-                               sender.getID(), senderData.position, senderData.speed, senderData.laneID, senderData.lanePos, receiver.currentlySeen);
+                    enterRange(0., receiverData, sender.getID(), senderData, receiver.currentlySeen);
                 } else {
-                    addRecognitionPoint(SIMTIME, receiverData.position, receiverData.speed, receiverData.laneID, receiverData.lanePos,
-                                        senderData.position, senderData.speed, senderData.laneID, senderData.lanePos, receiver.currentlySeen[sender.getID()]);
+                    addRecognitionPoint(SIMTIME, receiverData, senderData, receiver.currentlySeen[sender.getID()]);
                 }
             } else {
                 if (receiver.currentlySeen.find(sender.getID()) != receiver.currentlySeen.end()) {
-                    leaveRange(receiver.currentlySeen, receiver.seen, receiverData.position, receiverData.speed, receiverData.laneID, receiverData.lanePos,
-                               sender.getID(), senderData.position, senderData.speed, senderData.laneID, senderData.lanePos, 0.);
+                    leaveRange(receiver, receiverData, sender, senderData, 0.);
                 }
             }
             break;
         case 1: {
             // one intersection -> other vehicle either enters or leaves the range
-            const Position intersection1Sender = oldSenderPosition + senderDelta * intersections.front();
-            const Position intersection1Receiver = oldReceiverPosition + receiverDelta * intersections.front();
+            MSDevice_BTsender::VehicleState intersection1ReceiverData(receiverData);
+            intersection1ReceiverData.position = oldReceiverPosition + receiverDelta * intersections.front();
+            MSDevice_BTsender::VehicleState intersection1SenderData(senderData);
+            intersection1SenderData.position = oldSenderPosition + senderDelta * intersections.front();
             if (receiver.currentlySeen.find(sender.getID()) != receiver.currentlySeen.end()) {
-                leaveRange(receiver.currentlySeen, receiver.seen, intersection1Receiver, receiverData.speed, receiverData.laneID, receiverData.lanePos,
-                           sender.getID(), intersection1Sender, senderData.speed, senderData.laneID, senderData.lanePos, (intersections.front() - 1.) * TS);
+                leaveRange(receiver, intersection1ReceiverData,
+                           sender, intersection1SenderData, (intersections.front() - 1.) * TS);
             } else {
-                enterRange((intersections.front() - 1.) * TS, intersection1Receiver, receiverData.speed, receiverData.laneID, receiverData.lanePos,
-                           sender.getID(), intersection1Sender, senderData.speed, senderData.laneID, senderData.lanePos, receiver.currentlySeen);
+                enterRange((intersections.front() - 1.) * TS, intersection1ReceiverData,
+                           sender.getID(), intersection1SenderData, receiver.currentlySeen);
             }
         }
         break;
         case 2:
             // two intersections -> other vehicle enters and leaves the range
             if (receiver.currentlySeen.find(sender.getID()) == receiver.currentlySeen.end()) {
-                const Position intersection1Sender = oldSenderPosition + senderDelta * intersections.front();
-                const Position intersection1Receiver = oldReceiverPosition + receiverDelta * intersections.front();
-                enterRange((intersections.front() - 1.) * TS, intersection1Receiver, receiverData.speed, receiverData.laneID, receiverData.lanePos,
-                           sender.getID(), intersection1Sender, senderData.speed, senderData.laneID, senderData.lanePos, receiver.currentlySeen);
-                const Position intersection2Sender = oldSenderPosition + senderDelta * intersections.back();
-                const Position intersection2Receiver = oldReceiverPosition + receiverDelta * intersections.back();
-                leaveRange(receiver.currentlySeen, receiver.seen, intersection2Receiver, receiverData.speed, receiverData.laneID, receiverData.lanePos,
-                           sender.getID(), intersection2Sender, senderData.speed, senderData.laneID, senderData.lanePos, (intersections.back() - 1.) * TS);
+                MSDevice_BTsender::VehicleState intersectionReceiverData(receiverData);
+                intersectionReceiverData.position = oldReceiverPosition + receiverDelta * intersections.front();
+                MSDevice_BTsender::VehicleState intersectionSenderData(senderData);
+                intersectionSenderData.position = oldSenderPosition + senderDelta * intersections.front();
+                enterRange((intersections.front() - 1.) * TS, intersectionReceiverData,
+                           sender.getID(), intersectionSenderData, receiver.currentlySeen);
+                intersectionReceiverData.position = oldReceiverPosition + receiverDelta * intersections.back();
+                intersectionSenderData.position = oldSenderPosition + senderDelta * intersections.back();
+                leaveRange(receiver, intersectionReceiverData,
+                           sender, intersectionSenderData, (intersections.back() - 1.) * TS);
             } else {
-                WRITE_WARNING("The vehicle '" + sender.getID() + "' cannot be in the range of '" + receiver.getID() + "', leave, and enter it in one step.");
+                WRITE_WARNING("The vehicle '" + sender.getID() + "' cannot be in the range of vehicle '" + receiver.getID() + "', leave, and enter it in one step.");
             }
             break;
         default:
@@ -263,48 +262,77 @@ MSDevice_BTreceiver::BTreceiverUpdate::updateVisibility(MSDevice_BTreceiver::Veh
 
 
 void
-MSDevice_BTreceiver::BTreceiverUpdate::enterRange(SUMOReal atOffset,
-        const Position& thisPos, SUMOReal thisSpeed, const std::string& thisLaneID, SUMOReal thisLanePos,
-        const std::string& otherID, const Position& otherPos, SUMOReal otherSpeed, const std::string& otherLaneID, SUMOReal otherLanePos,
+MSDevice_BTreceiver::BTreceiverUpdate::enterRange(SUMOReal atOffset, const MSDevice_BTsender::VehicleState& receiverState,
+        const std::string& senderID, const MSDevice_BTsender::VehicleState& senderState,
         std::map<std::string, SeenDevice*>& currentlySeen) {
-    MeetingPoint mp(SIMTIME + atOffset, thisPos, thisSpeed, thisLaneID, thisLanePos, otherPos, otherSpeed, otherLaneID, otherLanePos);
+    MeetingPoint mp(SIMTIME + atOffset, receiverState, senderState);
     SeenDevice* sd = new SeenDevice(mp);
-    currentlySeen[otherID] = sd;
-    addRecognitionPoint(SIMTIME, thisPos, thisSpeed, thisLaneID, thisLanePos,
-                        otherPos, otherSpeed, otherLaneID, otherLanePos, sd);
+    currentlySeen[senderID] = sd;
+    addRecognitionPoint(SIMTIME, receiverState, senderState, sd);
 }
 
 
 void
-MSDevice_BTreceiver::BTreceiverUpdate::leaveRange(std::map<std::string, SeenDevice*>& currentlySeen, std::map<std::string, std::vector<SeenDevice*> >& seen,
-        const Position& thisPos, SUMOReal thisSpeed, const std::string& thisLaneID, SUMOReal thisLanePos,
-        const std::string& otherID, const Position& otherPos, SUMOReal otherSpeed, const std::string& otherLaneID, SUMOReal otherLanePos,
+MSDevice_BTreceiver::BTreceiverUpdate::leaveRange(VehicleInformation& receiverInfo, const MSDevice_BTsender::VehicleState& receiverState,
+        MSDevice_BTsender::VehicleInformation& senderInfo, const MSDevice_BTsender::VehicleState& senderState,
         SUMOReal tOffset) {
-    std::map<std::string, SeenDevice*>::iterator i = currentlySeen.find(otherID);
+    std::map<std::string, SeenDevice*>::iterator i = receiverInfo.currentlySeen.find(senderInfo.getID());
     // check whether the other was recognized
-    addRecognitionPoint(SIMTIME + tOffset, thisPos, thisSpeed, thisLaneID, thisLanePos,
-                        otherPos, otherSpeed, otherLaneID, otherLanePos, (*i).second);
+    addRecognitionPoint(SIMTIME + tOffset, receiverState, senderState, i->second);
     // build leaving point
-    MeetingPoint mp(STEPS2TIME(MSNet::getInstance()->getCurrentTimeStep()) + tOffset, thisPos, thisSpeed, thisLaneID, thisLanePos, otherPos, otherSpeed, otherLaneID, otherLanePos);
-    (*i).second->meetingEnd = mp;
-    if (seen.find(otherID) == seen.end()) {
-        seen[otherID] = std::vector<SeenDevice*>();
+    i->second->meetingEnd = new MeetingPoint(STEPS2TIME(MSNet::getInstance()->getCurrentTimeStep()) + tOffset, receiverState, senderState);
+    ConstMSEdgeVector::const_iterator begin = receiverInfo.route.begin() + i->second->meetingBegin.observerState.routePos;
+    ConstMSEdgeVector::const_iterator end = receiverInfo.route.begin() + receiverState.routePos + 1;
+    i->second->receiverRoute = toString<const MSEdge>(begin, end);
+    begin = senderInfo.route.begin() + i->second->meetingBegin.seenState.routePos;
+    end = senderInfo.route.begin() + senderState.routePos + 1;
+    i->second->senderRoute = toString<const MSEdge>(begin, end);
+    receiverInfo.seen[senderInfo.getID()].push_back(i->second);
+    receiverInfo.currentlySeen.erase(i);
+}
+
+
+SUMOReal
+MSDevice_BTreceiver::inquiryDelaySlots(const int backoffLimit) {
+    const int phaseOffset = sRecognitionRNG.randInt(2047);
+    const bool interlaced = sRecognitionRNG.rand() < 0.7;
+    const SUMOReal delaySlots = sRecognitionRNG.rand() * 15;
+    const int backoff = sRecognitionRNG.randInt(backoffLimit);
+    if (interlaced) {
+        return sRecognitionRNG.rand() * 31 + backoff;
     }
-    seen[otherID].push_back((*i).second);
-    currentlySeen.erase(i);
+    if (sRecognitionRNG.randInt(31) < 16) {
+        // correct train for f0
+        return delaySlots + backoff;
+    }
+    if (sRecognitionRNG.randInt(30) < 16) {
+        // correct train for f1
+        return 2048 - phaseOffset + delaySlots + backoff;
+    }
+    if (sRecognitionRNG.randInt(29) < 16) {
+        // f2 is in train A but has overlap with both trains
+        if (2 * 2048 - phaseOffset + backoff < 4096) {
+            return 2 * 2048 - phaseOffset + delaySlots + backoff;
+        }
+        // the following is wrong but should only happen in about 3% of the non-interlaced cases
+        return 2 * 2048 - phaseOffset + delaySlots + backoff;
+    }
+    return 2 * 2048 + delaySlots + backoff;
 }
 
 
 void
-MSDevice_BTreceiver::BTreceiverUpdate::addRecognitionPoint(const SUMOReal tEnd, const Position& thisPos, const SUMOReal thisSpeed, const std::string& thisLaneID, const SUMOReal thisLanePos,
-        const Position& otherPos, const SUMOReal otherSpeed, const std::string& otherLaneID, const SUMOReal otherLanePos,
-        SeenDevice* otherDevice) const {
-    const SUMOReal t = tEnd - MAX2(SIMTIME - TS, otherDevice->lastView);
-    // probability of a miss 0.5 (may be in the wrong train), backoff time 0.64s
-    if (sRecognitionRNG.rand() <= 1 - pow(0.5, t / myOffTime)) {
-        otherDevice->lastView = tEnd;
-        MeetingPoint* mp = new MeetingPoint(tEnd, thisPos, thisSpeed, thisLaneID, thisLanePos, otherPos, otherSpeed, otherLaneID, otherLanePos);
-        otherDevice->recognitionPoints.push_back(mp);
+MSDevice_BTreceiver::BTreceiverUpdate::addRecognitionPoint(const SUMOReal tEnd, const MSDevice_BTsender::VehicleState& receiverState,
+        const MSDevice_BTsender::VehicleState& senderState,
+        SeenDevice* senderDevice) const {
+    if (senderDevice->nextView == -1.) {
+        senderDevice->nextView = senderDevice->lastView + inquiryDelaySlots(int(myOffTime / 0.000625 + .5)) * 0.000625;
+    }
+    if (tEnd > senderDevice->nextView) {
+        senderDevice->lastView = senderDevice->nextView;
+        MeetingPoint* mp = new MeetingPoint(tEnd, receiverState, senderState);
+        senderDevice->recognitionPoints.push_back(mp);
+        senderDevice->nextView = senderDevice->lastView + inquiryDelaySlots(int(myOffTime / 0.000625 + .5)) * 0.000625;
     }
 }
 
@@ -317,22 +345,27 @@ MSDevice_BTreceiver::BTreceiverUpdate::writeOutput(const std::string& id, const
         const std::vector<SeenDevice*>& sts = (*j).second;
         for (std::vector<SeenDevice*>::const_iterator k = sts.begin(); k != sts.end(); ++k) {
             os.openTag("seen").writeAttr("id", (*j).first);
+            const MSDevice_BTsender::VehicleState& obsBeg = (*k)->meetingBegin.observerState;
+            const MSDevice_BTsender::VehicleState& seenBeg = (*k)->meetingBegin.seenState;
             os.writeAttr("tBeg", (*k)->meetingBegin.t)
-            .writeAttr("observerPosBeg", (*k)->meetingBegin.observerPos).writeAttr("observerSpeedBeg", (*k)->meetingBegin.observerSpeed)
-            .writeAttr("observerLaneIDBeg", (*k)->meetingBegin.observerLaneID).writeAttr("observerLanePosBeg", (*k)->meetingBegin.observerLanePos)
-            .writeAttr("seenPosBeg", (*k)->meetingBegin.seenPos).writeAttr("seenSpeedBeg", (*k)->meetingBegin.seenSpeed)
-            .writeAttr("seenLaneIDBeg", (*k)->meetingBegin.seenLaneID).writeAttr("seenLanePosBeg", (*k)->meetingBegin.seenLanePos);
-            os.writeAttr("tEnd", (*k)->meetingEnd.t)
-            .writeAttr("observerPosEnd", (*k)->meetingEnd.observerPos).writeAttr("observerSpeedEnd", (*k)->meetingEnd.observerSpeed)
-            .writeAttr("observerLaneIDEnd", (*k)->meetingEnd.observerLaneID).writeAttr("observerLanePosEnd", (*k)->meetingEnd.observerLanePos)
-            .writeAttr("seenPosEnd", (*k)->meetingEnd.seenPos).writeAttr("seenSpeedEnd", (*k)->meetingEnd.seenSpeed)
-            .writeAttr("seenLaneIDEnd", (*k)->meetingEnd.seenLaneID).writeAttr("seenLanePosEnd", (*k)->meetingEnd.seenLanePos);
+            .writeAttr("observerPosBeg", obsBeg.position).writeAttr("observerSpeedBeg", obsBeg.speed)
+            .writeAttr("observerLaneIDBeg", obsBeg.laneID).writeAttr("observerLanePosBeg", obsBeg.lanePos)
+            .writeAttr("seenPosBeg", seenBeg.position).writeAttr("seenSpeedBeg", seenBeg.speed)
+            .writeAttr("seenLaneIDBeg", seenBeg.laneID).writeAttr("seenLanePosBeg", seenBeg.lanePos);
+            const MSDevice_BTsender::VehicleState& obsEnd = (*k)->meetingEnd->observerState;
+            const MSDevice_BTsender::VehicleState& seenEnd = (*k)->meetingEnd->seenState;
+            os.writeAttr("tEnd", (*k)->meetingEnd->t)
+            .writeAttr("observerPosEnd", obsEnd.position).writeAttr("observerSpeedEnd", obsEnd.speed)
+            .writeAttr("observerLaneIDEnd", obsEnd.laneID).writeAttr("observerLanePosEnd", obsEnd.lanePos)
+            .writeAttr("seenPosEnd", seenEnd.position).writeAttr("seenSpeedEnd", seenEnd.speed)
+            .writeAttr("seenLaneIDEnd", seenEnd.laneID).writeAttr("seenLanePosEnd", seenEnd.lanePos)
+            .writeAttr("observerRoute", (*k)->receiverRoute).writeAttr("seenRoute", (*k)->senderRoute);
             for (std::vector<MeetingPoint*>::iterator l = (*k)->recognitionPoints.begin(); l != (*k)->recognitionPoints.end(); ++l) {
                 os.openTag("recognitionPoint").writeAttr("t", (*l)->t)
-                .writeAttr("observerPos", (*l)->observerPos).writeAttr("observerSpeed", (*l)->observerSpeed)
-                .writeAttr("observerLaneID", (*l)->observerLaneID).writeAttr("observerLanePos", (*l)->observerLanePos)
-                .writeAttr("seenPos", (*l)->seenPos).writeAttr("seenSpeed", (*l)->seenSpeed)
-                .writeAttr("seenLaneID", (*l)->seenLaneID).writeAttr("seenLanePos", (*l)->seenLanePos)
+                .writeAttr("observerPos", (*l)->observerState.position).writeAttr("observerSpeed", (*l)->observerState.speed)
+                .writeAttr("observerLaneID", (*l)->observerState.laneID).writeAttr("observerLanePos", (*l)->observerState.lanePos)
+                .writeAttr("seenPos", (*l)->seenState.position).writeAttr("seenSpeed", (*l)->seenState.speed)
+                .writeAttr("seenLaneID", (*l)->seenState.laneID).writeAttr("seenLanePos", (*l)->seenState.lanePos)
                 .closeTag();
                 if (!allRecognitions) {
                     break;
@@ -363,11 +396,16 @@ bool
 MSDevice_BTreceiver::notifyEnter(SUMOVehicle& veh, Notification reason) {
     if (reason == MSMoveReminder::NOTIFICATION_DEPARTED && sVehicles.find(veh.getID()) == sVehicles.end()) {
         sVehicles[veh.getID()] = new VehicleInformation(veh.getID(), myRange);
+        sVehicles[veh.getID()]->route.push_back(veh.getEdge());
     }
     if (reason == MSMoveReminder::NOTIFICATION_TELEPORT && sVehicles.find(veh.getID()) != sVehicles.end()) {
         sVehicles[veh.getID()]->amOnNet = true;
     }
-    sVehicles[veh.getID()]->updates.push_back(MSDevice_BTsender::VehicleState(veh.getSpeed(), static_cast<MSVehicle&>(veh).getPosition(), static_cast<MSVehicle&>(veh).getLane()->getID(), veh.getPositionOnLane()));
+    if (reason == MSMoveReminder::NOTIFICATION_TELEPORT || reason == MSMoveReminder::NOTIFICATION_JUNCTION) {
+        sVehicles[veh.getID()]->route.push_back(veh.getEdge());
+    }
+    const MSVehicle& v = static_cast<MSVehicle&>(veh);
+    sVehicles[veh.getID()]->updates.push_back(MSDevice_BTsender::VehicleState(veh.getSpeed(), veh.getPosition(), v.getLane()->getID(), veh.getPositionOnLane(), v.getRoutePosition()));
     return true;
 }
 
@@ -375,10 +413,11 @@ MSDevice_BTreceiver::notifyEnter(SUMOVehicle& veh, Notification reason) {
 bool
 MSDevice_BTreceiver::notifyMove(SUMOVehicle& veh, SUMOReal /* oldPos */, SUMOReal newPos, SUMOReal newSpeed) {
     if (sVehicles.find(veh.getID()) == sVehicles.end()) {
-        WRITE_WARNING("btreceiver: Can not update position of a vehicle that is not within the road network (" + veh.getID() + ").");
+        WRITE_WARNING("btreceiver: Can not update position of vehicle '" + veh.getID() + "' which is not on the road.");
         return true;
     }
-    sVehicles[veh.getID()]->updates.push_back(MSDevice_BTsender::VehicleState(newSpeed, static_cast<MSVehicle&>(veh).getPosition(), static_cast<MSVehicle&>(veh).getLane()->getID(), newPos));
+    const MSVehicle& v = static_cast<MSVehicle&>(veh);
+    sVehicles[veh.getID()]->updates.push_back(MSDevice_BTsender::VehicleState(newSpeed, veh.getPosition(), v.getLane()->getID(), newPos, v.getRoutePosition()));
     return true;
 }
 
@@ -389,10 +428,11 @@ MSDevice_BTreceiver::notifyLeave(SUMOVehicle& veh, SUMOReal /* lastPos */, Notif
         return true;
     }
     if (sVehicles.find(veh.getID()) == sVehicles.end()) {
-        WRITE_WARNING("btreceiver: Can not update position of a vehicle that is not within the road network (" + veh.getID() + ").");
+        WRITE_WARNING("btreceiver: Can not update position of vehicle '" + veh.getID() + "' which is not on the road.");
         return true;
     }
-    sVehicles[veh.getID()]->updates.push_back(MSDevice_BTsender::VehicleState(veh.getSpeed(), static_cast<MSVehicle&>(veh).getPosition(), static_cast<MSVehicle&>(veh).getLane()->getID(), veh.getPositionOnLane()));
+    const MSVehicle& v = static_cast<MSVehicle&>(veh);
+    sVehicles[veh.getID()]->updates.push_back(MSDevice_BTsender::VehicleState(veh.getSpeed(), veh.getPosition(), v.getLane()->getID(), veh.getPositionOnLane(), v.getRoutePosition()));
     if (reason == MSMoveReminder::NOTIFICATION_TELEPORT) {
         sVehicles[veh.getID()]->amOnNet = false;
     }
