@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Fri, 30.01.2009
-/// @version $Id: MSDevice_Tripinfo.cpp 17262 2014-11-04 20:41:44Z behrisch $
+/// @version $Id: MSDevice_Tripinfo.cpp 20674 2016-05-09 14:44:37Z namdre $
 ///
 // A device which collects info on the vehicle trip
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2009-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2009-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -51,6 +51,13 @@
 // ===========================================================================
 MSDevice_Tripinfo::DeviceSet MSDevice_Tripinfo::myPendingOutput;
 
+SUMOReal MSDevice_Tripinfo::myVehicleCount(0);
+SUMOReal MSDevice_Tripinfo::myTotalRouteLength(0);
+SUMOTime MSDevice_Tripinfo::myTotalDuration(0);
+SUMOTime MSDevice_Tripinfo::myTotalWaitingTime(0);
+SUMOTime MSDevice_Tripinfo::myTotalTimeLoss(0);
+SUMOTime MSDevice_Tripinfo::myTotalDepartDelay(0);
+
 // ===========================================================================
 // method definitions
 // ===========================================================================
@@ -59,7 +66,7 @@ MSDevice_Tripinfo::DeviceSet MSDevice_Tripinfo::myPendingOutput;
 // ---------------------------------------------------------------------------
 void
 MSDevice_Tripinfo::buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into) {
-    if (OptionsCont::getOptions().isSet("tripinfo-output")) {
+    if (OptionsCont::getOptions().isSet("tripinfo-output") || OptionsCont::getOptions().getBool("duration-log.statistics")) {
         MSDevice_Tripinfo* device = new MSDevice_Tripinfo(v, "tripinfo_" + v.getID());
         into.push_back(device);
         myPendingOutput.insert(device);
@@ -73,7 +80,6 @@ MSDevice_Tripinfo::buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& i
 MSDevice_Tripinfo::MSDevice_Tripinfo(SUMOVehicle& holder, const std::string& id) :
     MSDevice(holder, id),
     myDepartLane(""),
-    myDepartPos(-1),
     myDepartSpeed(-1),
     myWaitingSteps(0),
     myArrivalTime(NOT_ARRIVED),
@@ -93,6 +99,9 @@ MSDevice_Tripinfo::~MSDevice_Tripinfo() {
 bool
 MSDevice_Tripinfo::notifyMove(SUMOVehicle& veh, SUMOReal /*oldPos*/,
                               SUMOReal /*newPos*/, SUMOReal newSpeed) {
+    if (veh.isStopped()) {
+        return true;
+    }
     if (newSpeed <= SUMO_const_haltingSpeed) {
         myWaitingSteps++;
     }
@@ -110,13 +119,23 @@ MSDevice_Tripinfo::notifyMove(SUMOVehicle& veh, SUMOReal /*oldPos*/,
 }
 
 
+void
+MSDevice_Tripinfo::notifyMoveInternal(SUMOVehicle& veh, SUMOReal timeOnLane, SUMOReal speed) {
+    // called by meso
+    const SUMOReal vmax = veh.getEdge()->getVehicleMaxSpeed(&veh);
+    if (vmax > 0) {
+        myTimeLoss += TIME2STEPS(timeOnLane - (timeOnLane * speed / vmax));
+    }
+    myWaitingSteps += veh.getWaitingTime() / DELTA_T;
+}
+
+
 bool
 MSDevice_Tripinfo::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason) {
     if (reason == MSMoveReminder::NOTIFICATION_DEPARTED) {
         if (!MSGlobals::gUseMesoSim) {
             myDepartLane = static_cast<MSVehicle&>(veh).getLane()->getID();
         }
-        myDepartPos = veh.getPositionOnLane();
         myDepartSpeed = veh.getSpeed();
     }
     return true;
@@ -133,40 +152,68 @@ MSDevice_Tripinfo::notifyLeave(SUMOVehicle& veh, SUMOReal /*lastPos*/,
         }
         // @note vehicle may have moved past its arrivalPos during the last step
         // due to non-zero arrivalspeed but we consider it as arrived at the desired position
-        myArrivalPos = myHolder.getArrivalPos();
+        // However, vaporization may happen anywhere (via TraCI)
+        if (reason == MSMoveReminder::NOTIFICATION_VAPORIZED) {
+            myArrivalPos = veh.getPositionOnLane();
+        } else {
+            myArrivalPos = myHolder.getArrivalPos();
+        }
         myArrivalSpeed = veh.getSpeed();
     }
     return true;
 }
 
+void
+MSDevice_Tripinfo::computeLengthAndDuration(SUMOReal& routeLength, SUMOTime& duration) const {
+    SUMOTime finalTime;
+    SUMOReal finalPos;
+    SUMOReal finalPosOnInternal = 0;
+    if (myArrivalTime == NOT_ARRIVED) {
+        finalTime = MSNet::getInstance()->getCurrentTimeStep();
+        finalPos = myHolder.getPositionOnLane();
+        if (!MSGlobals::gUseMesoSim) {
+            const MSLane* lane = static_cast<MSVehicle&>(myHolder).getLane();
+            if (lane->getEdge().isInternal()) {
+                finalPosOnInternal = finalPos;
+                finalPos = myHolder.getEdge()->getLength();
+            }
+        }
+    } else {
+        finalTime = myArrivalTime;
+        finalPos = myArrivalPos;
+    }
+    const bool includeInternalLengths = MSGlobals::gUsingInternalLanes && MSNet::getInstance()->hasInternalLinks();
+    routeLength = myHolder.getRoute().getDistanceBetween(myHolder.getDepartPos(), finalPos,
+                  myHolder.getRoute().begin(), myHolder.getCurrentRouteEdge(), includeInternalLengths) + finalPosOnInternal;
+
+    duration = finalTime - myHolder.getDeparture();
+}
+
 
 void
 MSDevice_Tripinfo::generateOutput() const {
+    updateStatistics();
+    if (!OptionsCont::getOptions().isSet("tripinfo-output")) {
+        return;
+    }
     myPendingOutput.erase(this);
-    SUMOReal routeLength = myHolder.getRoute().getLength();
-    routeLength -= myDepartPos;
-    if (myArrivalLane != "") {
-        routeLength -= MSLane::dictionary(myArrivalLane)->getLength() - myArrivalPos;
-    }
-    SUMOTime exit = myArrivalTime;
-    if (myArrivalTime == NOT_ARRIVED) {
-        exit = MSNet::getInstance()->getCurrentTimeStep();
-        routeLength = myHolder.getRoute().getDistanceBetween(myDepartPos, myHolder.getPositionOnLane(),
-                      *myHolder.getRoute().begin(), myHolder.getEdge(), false);
-    }
+    SUMOReal routeLength;
+    SUMOTime duration;
+    computeLengthAndDuration(routeLength, duration);
+
     // write
     OutputDevice& os = OutputDevice::getDeviceByOption("tripinfo-output");
     os.openTag("tripinfo").writeAttr("id", myHolder.getID());
     os.writeAttr("depart", time2string(myHolder.getDeparture()));
     os.writeAttr("departLane", myDepartLane);
-    os.writeAttr("departPos", myDepartPos);
+    os.writeAttr("departPos", myHolder.getDepartPos());
     os.writeAttr("departSpeed", myDepartSpeed);
-    os.writeAttr("departDelay", time2string(myHolder.getDeparture() - myHolder.getParameter().depart));
+    os.writeAttr("departDelay", time2string(myHolder.getDepartDelay()));
     os.writeAttr("arrival", time2string(myArrivalTime));
     os.writeAttr("arrivalLane", myArrivalLane);
     os.writeAttr("arrivalPos", myArrivalPos);
     os.writeAttr("arrivalSpeed", myArrivalSpeed);
-    os.writeAttr("duration", time2string(exit - myHolder.getDeparture()));
+    os.writeAttr("duration", time2string(duration));
     os.writeAttr("routeLength", routeLength);
     os.writeAttr("waitSteps", myWaitingSteps);
     os.writeAttr("timeLoss", time2string(myTimeLoss));
@@ -192,6 +239,9 @@ MSDevice_Tripinfo::generateOutputForUnfinished() {
         const MSDevice_Tripinfo* d = *myPendingOutput.begin();
         if (d->myHolder.hasDeparted()) {
             d->generateOutput();
+            if (!OptionsCont::getOptions().isSet("tripinfo-output")) {
+                return;
+            }
             // @todo also generate emission output if holder has a device
             OutputDevice::getDeviceByOption("tripinfo-output").closeTag();
         } else {
@@ -201,6 +251,81 @@ MSDevice_Tripinfo::generateOutputForUnfinished() {
 }
 
 
+void
+MSDevice_Tripinfo::updateStatistics() const {
+    SUMOReal routeLength;
+    SUMOTime duration;
+    computeLengthAndDuration(routeLength, duration);
+
+    myVehicleCount++;
+    myTotalRouteLength += routeLength;
+    myTotalDuration += duration;
+    myTotalWaitingTime += (SUMOTime)(myWaitingSteps * DELTA_T);
+    myTotalTimeLoss += myTimeLoss;
+    myTotalDepartDelay += myHolder.getDepartDelay();
+}
+
+
+std::string
+MSDevice_Tripinfo::printStatistics() {
+    std::ostringstream msg;
+    msg.setf(msg.fixed);
+    msg.precision(OUTPUT_ACCURACY);
+    msg << "Statistics (avg):\n"
+        << " RouteLength: " << getAvgRouteLength() << "\n"
+        << " Duration: " << getAvgDuration() << "\n"
+        << " WaitingTime: " << getAvgWaitingTime() << "\n"
+        << " TimeLoss: " << getAvgTimeLoss() << "\n"
+        << " DepartDelay: " << getAvgDepartDelay() << "\n";
+    return msg.str();
+}
+
+
+SUMOReal
+MSDevice_Tripinfo::getAvgRouteLength() {
+    if (myVehicleCount > 0) {
+        return myTotalRouteLength / myVehicleCount;
+    } else {
+        return 0;
+    }
+}
+
+SUMOReal
+MSDevice_Tripinfo::getAvgDuration() {
+    if (myVehicleCount > 0) {
+        return STEPS2TIME(myTotalDuration / myVehicleCount);
+    } else {
+        return 0;
+    }
+}
+
+SUMOReal
+MSDevice_Tripinfo::getAvgWaitingTime() {
+    if (myVehicleCount > 0) {
+        return STEPS2TIME(myTotalWaitingTime / myVehicleCount);
+    } else {
+        return 0;
+    }
+}
+
+SUMOReal
+MSDevice_Tripinfo::getAvgTimeLoss() {
+    if (myVehicleCount > 0) {
+        return STEPS2TIME(myTotalTimeLoss / myVehicleCount);
+    } else {
+        return 0;
+    }
+}
+
+SUMOReal
+MSDevice_Tripinfo::getAvgDepartDelay() {
+    if (myVehicleCount > 0) {
+        return STEPS2TIME(myTotalDepartDelay / myVehicleCount);
+    } else {
+        return 0;
+    }
+}
+
 
 /****************************************************************************/
 
