@@ -4,7 +4,7 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Fri, 30.01.2009
-/// @version $Id: MSDevice_Tripinfo.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: MSDevice_Tripinfo.h 21182 2016-07-18 06:46:01Z behrisch $
 ///
 // A device which collects info on the vehicle trip
 /****************************************************************************/
@@ -170,7 +170,7 @@ private:
     SUMOReal myDepartSpeed;
 
     /// @brief The overall number of waiting steps
-    unsigned int myWaitingSteps;
+    int myWaitingSteps;
 
     /// @brief The vehicle's arrival time
     SUMOTime myArrivalTime;
