@@ -6,12 +6,12 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Tue Dec 02 2003 22:17 CET
-/// @version $Id: MSE3Collector.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MSE3Collector.cpp 21201 2016-07-19 11:57:22Z behrisch $
 ///
 // A detector of vehicles passing an area between entry/exit points
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -206,7 +206,7 @@ MSE3Collector::writeXMLOutput(OutputDevice& dev,
                               SUMOTime startTime, SUMOTime stopTime) {
     dev << "   <interval begin=\"" << time2string(startTime) << "\" end=\"" << time2string(stopTime) << "\" " << "id=\"" << myID << "\" ";
     // collect values about vehicles that have left the area
-    unsigned vehicleSum = (unsigned) myLeftContainer.size();
+    int vehicleSum = (int) myLeftContainer.size();
     SUMOReal meanTravelTime = 0.;
     SUMOReal meanSpeed = 0.;
     SUMOReal meanHaltsPerVehicle = 0.;
@@ -223,7 +223,7 @@ MSE3Collector::writeXMLOutput(OutputDevice& dev,
     myLeftContainer.clear();
 
     // collect values about vehicles within the container
-    unsigned vehicleSumWithin = (unsigned) myEnteredContainer.size();
+    int vehicleSumWithin = (int) myEnteredContainer.size();
     SUMOReal meanSpeedWithin = 0.;
     SUMOReal meanDurationWithin = 0.;
     SUMOReal meanHaltsPerVehicleWithin = 0.;
@@ -291,7 +291,7 @@ MSE3Collector::detectorUpdate(const SUMOTime step) {
         values.intervalSpeedSum += veh->getSpeed() * TS;
         if (veh->getSpeed() < myHaltingSpeedThreshold) {
             if (values.haltingBegin == -1) {
-                values.haltingBegin = step;
+                values.haltingBegin = STEPS2TIME(step);
             }
             if (step - values.haltingBegin > myHaltingTimeThreshold) {
                 values.haltings++;
