@@ -2,12 +2,12 @@
 /// @file    MSFCDExport.h
 /// @author  Mario Krumnow
 /// @date    2012-04-26
-/// @version $Id: MSFCDExport.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MSFCDExport.h 20433 2016-04-13 08:00:14Z behrisch $
 ///
 // Realises dumping Floating Car Data (FCD) Data
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2012-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2012-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -56,16 +56,20 @@ class MSLane;
  */
 class MSFCDExport {
 public:
-    /** @brief Writes the posion and the angle of each vehcile into the given device
+    /** @brief Writes the position and the angle of each vehicle into the given device
      *
      *  Opens the current time step and export the values vehicle id, position and angle
      *
      * @param[in] of The output device to use
      * @param[in] timestep The current time step
+     * @param[in] elevation Whether elevation data shall be written
      * @exception IOError If an error on writing occurs (!!! not yet implemented)
      */
-    static void write(OutputDevice& of, SUMOTime timestep);
+    static void write(OutputDevice& of, SUMOTime timestep, bool elevation);
 
+private:
+    /// @brief write transportable
+    static void writeTransportable(OutputDevice& of, const MSEdge* e, MSTransportable* p, SumoXMLTag tag, bool useGeo, bool elevation);
 
 private:
     /// @brief Invalidated copy constructor.
