@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Mon, 10.05.2004
-/// @version $Id: MSMeanData_Net.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MSMeanData_Net.h 21201 2016-07-19 11:57:22Z behrisch $
 ///
 // Network state mean data collector for edges/lanes
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2004-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2004-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -155,29 +155,29 @@ public:
         /// @name Collected values
         /// @{
         /// @brief The number of vehicles that were emitted on the lane
-        unsigned nVehDeparted;
+        int nVehDeparted;
 
         /// @brief The number of vehicles that finished on the lane
-        unsigned nVehArrived;
+        int nVehArrived;
 
         /// @brief The number of vehicles that entered this lane within the sample interval
-        unsigned nVehEntered;
+        int nVehEntered;
 
         /// @brief The number of vehicles that left this lane within the sample interval
-        unsigned nVehLeft;
+        int nVehLeft;
 
         /// @brief The number of vehicles that left this lane within the sample interval
-        unsigned nVehVaporized;
+        int nVehVaporized;
 
         /// @brief The number of vehicle probes with small speed
         SUMOReal waitSeconds;
 
     private:
         /// @brief The number of vehicles that changed from this lane
-        unsigned nVehLaneChangeFrom;
+        int nVehLaneChangeFrom;
 
         /// @brief The number of vehicles that changed to this lane
-        unsigned nVehLaneChangeTo;
+        int nVehLaneChangeTo;
 
 
         /// @brief The sum of the lengths the vehicles had
