@@ -3,7 +3,7 @@
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    02. March 2012
-/// @version $Id: NBAlgorithms.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NBAlgorithms.h 21201 2016-07-19 11:57:22Z behrisch $
 ///
 // Algorithms for network computation
 /****************************************************************************/
@@ -127,10 +127,10 @@ public:
 
     private:
         /// @brief retrieves the minimum index in myAllEdges
-        size_t getMinRank(const EdgeVector& e) const {
-            size_t result = myOrdering.size();
+        int getMinRank(const EdgeVector& e) const {
+            int result = (int)myOrdering.size();
             for (EdgeVector::const_iterator it = e.begin(); it != e.end(); ++it) {
-                size_t rank = std::distance(myOrdering.begin(), std::find(myOrdering.begin(), myOrdering.end(), *it));
+                int rank = (int)std::distance(myOrdering.begin(), std::find(myOrdering.begin(), myOrdering.end(), *it));
                 result = MIN2(result, rank);
             }
             return result;
