@@ -5,12 +5,12 @@
 /// @author  Yun-Pang Floetteroed
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Nov 2001
-/// @version $Id: NBNode.h 18756 2015-08-31 19:16:33Z behrisch $
+/// @version $Id: NBNode.h 21182 2016-07-18 06:46:01Z behrisch $
 ///
 // The representation of a single node
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -43,7 +43,6 @@
 #include <utils/geom/Bresenham.h>
 #include <utils/common/VectorHelper.h>
 #include <utils/geom/Position.h>
-#include <utils/geom/Line.h>
 #include <utils/geom/PositionVector.h>
 #include <utils/xml/SUMOXMLDefinitions.h>
 #include "NBEdge.h"
@@ -102,7 +101,7 @@ public:
         NBEdge* myCurrentOutgoing;
 
         /// @brief The available lanes to which connections shall be built
-        std::vector<unsigned int> myAvailableLanes;
+        std::vector<int> myAvailableLanes;
 
     public:
         /** @brief Constructor
@@ -114,12 +113,12 @@ public:
         /// @brief Destructor
         ~ApproachingDivider();
 
-        unsigned int numAvailableLanes() const {
-            return (unsigned int)myAvailableLanes.size();
+        int numAvailableLanes() const {
+            return (int)myAvailableLanes.size();
         }
 
         /** the bresenham-callback */
-        void execute(const unsigned int src, const unsigned int dest);
+        void execute(const int src, const int dest);
 
         /** the method that spreads the wished number of lanes from the
             the lane given by the bresenham-call to both left and right */
@@ -132,8 +131,8 @@ public:
      */
     struct Crossing {
         Crossing(const NBNode* _node, const EdgeVector& _edges, SUMOReal _width, bool _priority) :
-            node(_node), edges(_edges), width(_width), priority(_priority), tlLinkNo(-1)
-        {}
+            node(_node), edges(_edges), width(_width), priority(_priority), tlLinkNo(-1) {
+        }
         /// @brief The parent node of this crossing
         const NBNode* node;
         /// @brief The edges being crossed
@@ -162,8 +161,8 @@ public:
         WalkingArea(const std::string& _id, SUMOReal _width) :
             id(_id),
             width(_width),
-            nextCrossing("")
-        {}
+            nextCrossing("") {
+        }
         /// @brief the (edge)-id of this walkingArea
         std::string id;
         /// @brief This lane's width
@@ -186,16 +185,10 @@ public:
     /// @brief default width of pedetrian crossings
     static const SUMOReal DEFAULT_CROSSING_WIDTH;
 
-    /// @brief the default turning radius at intersections in m
-    static const SUMOReal DEFAULT_RADIUS;
-
     /// @brief unspecified lane width
     static const SUMOReal UNSPECIFIED_RADIUS;
 
 public:
-    /// @brief maximum number of connections allowed
-    static const int MAX_CONNECTIONS;
-
     /** @brief Constructor
      * @param[in] id The id of the node
      * @param[in] position The position of the node
@@ -348,7 +341,7 @@ public:
      * @param[in, opt. changed] tc The traffic lights container to update
      * @return The number of removed edges
      */
-    unsigned int removeSelfLoops(NBDistrictCont& dc, NBEdgeCont& ec, NBTrafficLightLogicCont& tc);
+    int removeSelfLoops(NBDistrictCont& dc, NBEdgeCont& ec, NBTrafficLightLogicCont& tc);
     /// @}
 
 
@@ -440,10 +433,11 @@ public:
      * @param[in] from The connection's start edge
      * @param[in] to The connection's end edge
      * @param[in] fromLane The lane the connection start at
+     * @param[in] toLane The lane the connection ends at
      * @param[in] includePedCrossings Whether braking due to a pedestrian crossing counts
      * @return Whether the described connection must brake (has higher priorised foes)
      */
-    bool mustBrake(const NBEdge* const from, const NBEdge* const to, int fromLane, bool includePedCrossings) const;
+    bool mustBrake(const NBEdge* const from, const NBEdge* const to, int fromLane, int toLane, bool includePedCrossings) const;
 
     /** @brief Returns the information whether the described flow must brake for the given crossing
      * @param[in] from The connection's start edge
@@ -491,7 +485,7 @@ public:
     LinkDirection getDirection(const NBEdge* const incoming, const NBEdge* const outgoing, bool leftHand = false) const;
 
     LinkState getLinkState(const NBEdge* incoming, NBEdge* outgoing,
-                           int fromLane, bool mayDefinitelyPass, const std::string& tlID) const;
+                           int fromLane, int toLane, bool mayDefinitelyPass, const std::string& tlID) const;
 
     /** @brief Compute the junction shape for this node
      * @param[in] mismatchThreshold The threshold for warning about shapes which are away from myPosition
@@ -548,7 +542,7 @@ public:
      * @param[in] numPoints The number of geometry points for the internal lane
      * @return The shape of the internal lane
      */
-    PositionVector computeInternalLaneShape(NBEdge* fromE, const NBEdge::Connection& con, int numPoints = 5) const;
+    PositionVector computeInternalLaneShape(NBEdge* fromE, const NBEdge::Connection& con, int numPoints) const;
 
 
     /** @brief Compute a smooth curve between the given geometries
@@ -568,10 +562,16 @@ public:
         SUMOReal extrapolateBeg,
         SUMOReal extrapolateEnd) const;
 
+    static PositionVector bezierControlPoints(
+        const PositionVector& begShape,
+        const PositionVector& endShape,
+        bool isTurnaround,
+        SUMOReal extrapolateBeg,
+        SUMOReal extrapolateEnd);
 
     /** @brief Replaces occurences of the first edge within the list of incoming by the second
         Connections are remapped, too */
-    void replaceIncoming(NBEdge* which, NBEdge* by, unsigned int laneOff);
+    void replaceIncoming(NBEdge* which, NBEdge* by, int laneOff);
 
     /** @brief Replaces occurences of every edge from the given list within the list of incoming by the second
         Connections are remapped, too */
@@ -579,7 +579,7 @@ public:
 
     /** @brief Replaces occurences of the first edge within the list of outgoing by the second
         Connections are remapped, too */
-    void replaceOutgoing(NBEdge* which, NBEdge* by, unsigned int laneOff);
+    void replaceOutgoing(NBEdge* which, NBEdge* by, int laneOff);
 
     /** @brief Replaces occurences of every edge from the given list within the list of outgoing by the second
         Connections are remapped, too */
@@ -600,7 +600,7 @@ public:
     /* @brief build pedestrian crossings
      * @return The next index for creating internal lanes
      * */
-    unsigned int buildCrossings();
+    int buildCrossings();
 
     /* @brief build pedestrian walking areas and set connections from/to walkingAreas
      * @param[in] cornerDetail The detail level when generating the inner curve
@@ -656,7 +656,7 @@ public:
     const Crossing& getCrossing(const std::string& id) const;
 
     /// @brief set tl indices of this nodes crossing starting at the given index
-    void setCrossingTLIndices(unsigned int startIndex);
+    void setCrossingTLIndices(int startIndex);
 
     /// @brief return the number of lane-to-lane connections at this junction (excluding crossings)
     int numNormalConnections() const;
@@ -665,6 +665,8 @@ public:
      */
     void avoidOverlap();
 
+    /// @brief whether the given index must yield to the foeIndex while turing right on a red light
+    bool rightOnRedConflict(int index, int foeIndex) const;
 
     /**
      * @class nodes_by_id_sorter
@@ -704,6 +706,10 @@ public:
     /// @brief returns the node id for internal lanes, crossings and walkingareas
     static std::string getNodeIDFromInternalLane(const std::string id);
 
+
+    /// @brief return whether the given type is a traffic light
+    static bool isTrafficLight(SumoXMLNodeType type);
+
 private:
     bool isSimpleContinuation() const;
 
@@ -718,7 +724,7 @@ private:
 
 
     void replaceInConnectionProhibitions(NBEdge* which, NBEdge* by,
-                                         unsigned int whichLaneOff, unsigned int byLaneOff);
+                                         int whichLaneOff, int byLaneOff);
 
 
     void remapRemoved(NBTrafficLightLogicCont& tc,
@@ -732,6 +738,8 @@ private:
     /// @brief returns the list of all edges sorted clockwise by getAngleAtNodeToCenter
     EdgeVector getEdgesSortedByAngleAtNodeCenter() const;
 
+    static bool isLongEnough(NBEdge* out, SUMOReal minLength);
+
 private:
     /// @brief The position the node lies at
     Position myPosition;
