@@ -2,7 +2,7 @@
 /// @file    GNEChange_Lane.cpp
 /// @author  Jakob Erdmann
 /// @date    April 2011
-/// @version $Id: GNEChange_Lane.cpp 21143 2016-07-11 12:37:50Z palcraft $
+/// @version $Id: GNEChange_Lane.cpp 21224 2016-07-25 07:53:33Z namdre $
 ///
 // A network change in which a single lane is created or deleted
 /****************************************************************************/
@@ -54,13 +54,12 @@ GNEChange_Lane::GNEChange_Lane(GNEEdge* edge, GNELane* lane, const NBEdge::Lane&
     GNEChange(0, forward),
     myEdge(edge),
     myLane(lane),
-    myLaneAttrs(laneAttrs),
-    myAdditionalSets(myLane->getAdditionalSets()) {
+    myLaneAttrs(laneAttrs) {
     myEdge->incRef("GNEChange_Lane");
-    if (myLane) { 
-        // non-zero pointer is only passsed in case of removal
-        assert(!forward);
+    if (myLane) {
+        // non-zero pointer is passsed in case of removal or duplication
         myLane->incRef("GNEChange_Lane");
+        myAdditionalSets = myLane->getAdditionalSets();
     } else {
         assert(forward);
     }
@@ -86,17 +85,17 @@ void GNEChange_Lane::undo() {
     if (myForward) {
         myEdge->removeLane(myLane);
         // Remove references to this edge in their AdditionalSets
-        for(std::vector<GNEAdditionalSet*>::iterator i = myAdditionalSets.begin(); i != myAdditionalSets.end(); i++) {
+        for (std::vector<GNEAdditionalSet*>::iterator i = myAdditionalSets.begin(); i != myAdditionalSets.end(); i++) {
             (*i)->removeLaneChild(myLane);
             // Remove additional from net if the number of childs is >= 0
-            if((*i)->getNumberOfEdgeChilds() == 0) {
+            if ((*i)->getNumberOfEdgeChilds() == 0) {
                 myNet->deleteAdditional(*i);
             }
         }
     } else {
         myEdge->addLane(myLane, myLaneAttrs);
         // Add references to this edge in their AdditionalSets
-        for(std::vector<GNEAdditionalSet*>::iterator i = myAdditionalSets.begin(); i != myAdditionalSets.end(); i++) {
+        for (std::vector<GNEAdditionalSet*>::iterator i = myAdditionalSets.begin(); i != myAdditionalSets.end(); i++) {
             myNet->insertAdditional(*i, false);
             (*i)->addLaneChild(myLane);
         }
@@ -108,17 +107,17 @@ void GNEChange_Lane::redo() {
     if (myForward) {
         myEdge->addLane(myLane, myLaneAttrs);
         // Add references to this edge in their AdditionalSets
-        for(std::vector<GNEAdditionalSet*>::iterator i = myAdditionalSets.begin(); i != myAdditionalSets.end(); i++) {
+        for (std::vector<GNEAdditionalSet*>::iterator i = myAdditionalSets.begin(); i != myAdditionalSets.end(); i++) {
             myNet->insertAdditional(*i, false);
             (*i)->addLaneChild(myLane);
         }
     } else {
         myEdge->removeLane(myLane);
         // Remove references to this edge in their AdditionalSets
-        for(std::vector<GNEAdditionalSet*>::iterator i = myAdditionalSets.begin(); i != myAdditionalSets.end(); i++) {
+        for (std::vector<GNEAdditionalSet*>::iterator i = myAdditionalSets.begin(); i != myAdditionalSets.end(); i++) {
             (*i)->removeLaneChild(myLane);
             // Remove additional from net if the number of childs is >= 0
-            if((*i)->getNumberOfEdgeChilds() == 0) {
+            if ((*i)->getNumberOfEdgeChilds() == 0) {
                 myNet->deleteAdditional(*i);
             }
         }
