@@ -2,7 +2,7 @@
 /// @file    GNEJunction.cpp
 /// @author  Jakob Erdmann
 /// @date    Feb 2011
-/// @version $Id: GNEJunction.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GNEJunction.cpp 21194 2016-07-19 10:29:54Z namdre $
 ///
 // A class for visualizing and editing junctions in netedit (adapted from
 // GUIJunctionWrapper)
@@ -170,8 +170,9 @@ GNEJunction::getCenteringBoundary() const {
 void
 GNEJunction::drawGL(const GUIVisualizationSettings& s) const {
     glPushName(getGlID());
-    SUMOReal selectionScale = gSelected.isSelected(getType(), getGlID()) ? s.selectionScale : 1;
-    if (s.scale * selectionScale * myMaxSize < 1.) {
+    SUMOReal exaggeration = gSelected.isSelected(getType(), getGlID()) ? s.selectionScale : 1;
+    exaggeration *= s.junctionSize.getExaggeration(s);
+    if (s.scale * exaggeration * myMaxSize < 1.) {
         // draw something simple so that selection still works
         GLHelper::drawBoxLine(myNBNode.getPosition(), 0, 1, 1);
     } else {
@@ -180,28 +181,38 @@ GNEJunction::drawGL(const GUIVisualizationSettings& s) const {
         const bool drawBubble = (!drawShape || myNBNode.getShape().area() < 4) && s.drawJunctionShape; // magic threshold
 
         if (drawShape) {
-            glPushMatrix();
             setColor(s, false);
-            glTranslated(0, 0, getType());
-            PositionVector shape = myNBNode.getShape();
-            shape.closePolygon();
-            if (selectionScale > 1) {
-                shape.scaleRelative(selectionScale);
+            // recognize full transparency and simply don't draw
+            GLfloat color[4];
+            glGetFloatv(GL_CURRENT_COLOR, color);
+            if (color[3] != 0) {
+                glPushMatrix();
+                glTranslated(0, 0, getType());
+                PositionVector shape = myNBNode.getShape();
+                shape.closePolygon();
+                if (exaggeration > 1) {
+                    shape.scaleRelative(exaggeration);
+                }
+                if (s.scale * exaggeration * myMaxSize < 40.) {
+                    GLHelper::drawFilledPoly(shape, true);
+                } else {
+                    GLHelper::drawFilledPolyTesselated(shape, true);
+                }
+                glPopMatrix();
             }
-            if (s.scale * selectionScale * myMaxSize < 40.) {
-                GLHelper::drawFilledPoly(shape, true);
-            } else {
-                GLHelper::drawFilledPolyTesselated(shape, true);
-            }
-            glPopMatrix();
         }
         if (drawBubble) {
-            glPushMatrix();
             setColor(s, true);
-            Position pos = myNBNode.getPosition();
-            glTranslated(pos.x(), pos.y(), getType() - 0.05);
-            GLHelper::drawFilledCircle(4 * selectionScale, 32);
-            glPopMatrix();
+            // recognize full transparency and simply don't draw
+            GLfloat color[4];
+            glGetFloatv(GL_CURRENT_COLOR, color);
+            if (color[3] != 0) {
+                glPushMatrix();
+                Position pos = myNBNode.getPosition();
+                glTranslated(pos.x(), pos.y(), getType() - 0.05);
+                GLHelper::drawFilledCircle(4 * exaggeration, 32);
+                glPopMatrix();
+            }
         }
 
         if (s.editMode == GNE_MODE_TLS && myNBNode.isTLControlled() && !myAmTLSSelected) {
@@ -295,15 +306,20 @@ GNEJunction::setLogicValid(bool valid, GNEUndoList* undoList, const std::string&
     myHasValidLogic = valid;
     // If new logic isn't valid
     if (!valid) {
+
         // Check preconditions
         assert(undoList != 0);
         assert(undoList->hasCommandGroup());
+
         // Registre a modification of status
         undoList->add(new GNEChange_Attribute(this, GNE_ATTR_MODIFICATION_STATUS, status));
+
         // allow edges to recompute their connections
         NBTurningDirectionsComputer::computeTurnDirectionsForNode(&myNBNode, false);
+
         // Obtain a copy of incoming edges
         EdgeVector incoming = myNBNode.getIncomingEdges();
+
         // Iterate over incoming edges
         for (EdgeVector::iterator it = incoming.begin(); it != incoming.end(); it++) {
             NBEdge* srcNBE = *it;
@@ -597,8 +613,8 @@ GNEJunction::getColorValue(const GUIVisualizationSettings& s, bool bubble) const
 void
 GNEJunction::setColor(const GUIVisualizationSettings& s, bool bubble) const {
     GLHelper::setColor(s.junctionColorer.getScheme().getColor(getColorValue(s, bubble)));
-    // override with special colors
-    if (gSelected.isSelected(getType(), getGlID())) {
+    // override with special colors (unless the color scheme is based on selection)
+    if (gSelected.isSelected(getType(), getGlID()) && s.junctionColorer.getActive() != 1) {
         GLHelper::setColor(GNENet::selectionColor);
     }
     if (myAmCreateEdgeSource) {
