@@ -2,7 +2,7 @@
 /// @file    GNELoadThread.cpp
 /// @author  Jakob Erdmann
 /// @date    Feb 2011
-/// @version $Id: GNELoadThread.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GNELoadThread.cpp 21239 2016-07-26 09:33:31Z namdre $
 ///
 // The thread that performs the loading of a Netedit-net (adapted from
 // GUILoadThread)
@@ -31,6 +31,7 @@
 
 #include <iostream>
 #include <ctime>
+#include <utils/xml/XMLSubSys.h>
 #include <utils/gui/events/GUIEvent_Message.h>
 #include <utils/gui/windows/GUIAppEnum.h>
 #include <utils/gui/globjects/GUIGlObjectStorage.h>
@@ -113,6 +114,7 @@ GNELoadThread::run() {
         submitEndAndCleanup(net);
         return 0;
     }
+    XMLSubSys::setValidation(oc.getString("xml-validation"), oc.getString("xml-validation.net"));
     // this netbuilder instance becomes the responsibility of the GNENet
     NBNetBuilder* netBuilder = new NBNetBuilder();
 
