@@ -2,7 +2,7 @@
 /// @file    netedit_main.cpp
 /// @author  Jakob Erdmann
 /// @date    Feb 2011
-/// @version $Id: netedit_main.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: netedit_main.cpp 21172 2016-07-15 08:34:36Z behrisch $
 ///
 // Main for NETEDIT (adapted from guisim_main)
 /****************************************************************************/
@@ -81,6 +81,13 @@ main(int argc, char** argv) {
 #endif
         // initialise subsystems
         XMLSubSys::init();
+        GNELoadThread::fillOptions(oc);
+        OptionsIO::setArgs(argc, argv);
+        OptionsIO::getOptions(true);
+        if (oc.processMetaOptions(false)) {
+            SystemFrame::close();
+            return 0;
+        }
         // Make application
         FXApp application("Netedit", "DLR");
         // Open display
