@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Walter Bamberger
 /// @date    Mon, 14.04.2008
-/// @version $Id: NIImporter_OpenStreetMap.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NIImporter_OpenStreetMap.h 21202 2016-07-19 13:40:35Z behrisch $
 ///
 // Importer for networks stored in OpenStreetMap format
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -80,11 +80,11 @@ protected:
     /** @brief An internal representation of an OSM-node
      */
     struct NIOSMNode {
-        NIOSMNode(SUMOLong _id, double _lon, double _lat) :
+        NIOSMNode(long long int _id, double _lon, double _lat) :
             id(_id), lon(_lon), lat(_lat), ele(0), tlsControlled(false), node(0) {}
 
         /// @brief The node's id
-        const SUMOLong id;
+        const long long int id;
         /// @brief The longitude the node is located at
         const SUMOReal lon;
         /// @brief The latitude the node is located at
@@ -102,17 +102,31 @@ protected:
 
     };
 
+    /** @enum CycleWayType
+     * @brief details on the kind of cycleway along this road
+     */
+    enum WayType {
+        WAY_NONE = 0,
+        WAY_FORWARD = 1,
+        WAY_BACKWARD = 2,
+        WAY_BOTH = WAY_FORWARD | WAY_BACKWARD,
+        WAY_UNKNOWN = 4
+    };
+
 
     /** @brief An internal definition of a loaded edge
      */
     struct Edge {
 
-        Edge(SUMOLong _id) :
+        Edge(long long int _id) :
             id(_id), myNoLanes(-1), myNoLanesForward(0), myMaxSpeed(MAXSPEED_UNGIVEN),
+            myCyclewayType(WAY_UNKNOWN), // building of extra lane depends on bikelaneWidth of loaded typemap
+            myBuswayType(WAY_NONE), // buslanes are always built when declared
+            myLayer(0), // layer is non-zero only in conflict areas
             myCurrentIsRoad(false) {}
 
         /// @brief The edge's id
-        const SUMOLong id;
+        const long long int id;
         /// @brief The edge's street name
         std::string streetName;
         /// @brief number of lanes, or -1 if unknown
@@ -125,8 +139,14 @@ protected:
         std::string myHighWayType;
         /// @brief Information whether this is an one-way road
         std::string  myIsOneWay;
+        /// @brief Information about the kind of cycleway along this road
+        WayType myCyclewayType;
+        /// @brief Information about the kind of busway along this road
+        WayType myBuswayType;
+        /// @brief Information about the relative z-ordering of ways
+        int myLayer;
         /// @brief The list of nodes this edge is made of
-        std::vector<SUMOLong> myCurrentNodes;
+        std::vector<long long int> myCurrentNodes;
         /// @brief Information whether this is a road
         bool myCurrentIsRoad;
 
@@ -163,14 +183,14 @@ private:
     /** @brief the map from OSM node ids to actual nodes
      * @note: NIOSMNodes may appear multiple times due to substition
      */
-    std::map<SUMOLong, NIOSMNode*> myOSMNodes;
+    std::map<long long int, NIOSMNode*> myOSMNodes;
 
     /// @brief the set of unique nodes used in NodesHandler, used when freeing memory
     std::set<NIOSMNode*, CompareNodes> myUniqueNodes;
 
 
     /** @brief the map from OSM way ids to edge objects */
-    std::map<SUMOLong, Edge*> myEdges;
+    std::map<long long int, Edge*> myEdges;
 
     /// @brief The compounds types that do not contain known types
     std::set<std::string> myUnusableTypes;
@@ -192,7 +212,7 @@ private:
      * @return The built/found node
      * @exception ProcessError If the tls could not be added to the container
      */
-    NBNode* insertNodeChecking(SUMOLong id, NBNodeCont& nc, NBTrafficLightLogicCont& tlsc);
+    NBNode* insertNodeChecking(long long int id, NBNodeCont& nc, NBTrafficLightLogicCont& tlsc);
 
 
     /** @brief Builds an NBEdge
@@ -208,12 +228,17 @@ private:
      * @exception ProcessError If the edge could not be added to the container
      */
     int insertEdge(Edge* e, int index, NBNode* from, NBNode* to,
-                   const std::vector<SUMOLong>& passed, NBNetBuilder& nb);
+                   const std::vector<long long int>& passed, NBNetBuilder& nb);
 
+    /// @brief reconstruct elevation from layer info
+    void reconstructLayerElevation(SUMOReal layerElevation, NBNetBuilder& nb);
+
+    /// @brief collect neighboring nodes with their road distance
+    std::map<NBNode*, SUMOReal> getNeighboringNodes(NBNode* node, SUMOReal maxDist);
 
 protected:
     static const SUMOReal MAXSPEED_UNGIVEN;
-    static const SUMOLong INVALID_ID;
+    static const long long int INVALID_ID;
 
     /**
      * @class NodesHandler
@@ -227,7 +252,7 @@ protected:
          * @param[in, out] uniqueNodes The nodes container for ensuring uniqueness
          * @param[in] options The options to use
          */
-        NodesHandler(std::map<SUMOLong, NIOSMNode*>& toFill,
+        NodesHandler(std::map<long long int, NIOSMNode*>& toFill,
                      std::set<NIOSMNode*, CompareNodes>& uniqueNodes,
                      bool importElevation);
 
@@ -263,10 +288,10 @@ protected:
     private:
 
         /// @brief The nodes container to fill
-        std::map<SUMOLong, NIOSMNode*>& myToFill;
+        std::map<long long int, NIOSMNode*>& myToFill;
 
         /// @brief ID of the currently parsed node, for reporting mainly
-        SUMOLong myLastNodeID;
+        long long int myLastNodeID;
 
         /// @brief Hierarchy helper for parsing a node's tags
         bool myIsInValidNodeTag;
@@ -303,8 +328,8 @@ protected:
          * @param[in] osmNodes The previously parsed (osm-)nodes
          * @param[in, out] toFill The edges container to fill with read edges
          */
-        EdgesHandler(const std::map<SUMOLong, NIOSMNode*>& osmNodes,
-                     std::map<SUMOLong, Edge*>& toFill);
+        EdgesHandler(const std::map<long long int, NIOSMNode*>& osmNodes,
+                     std::map<long long int, Edge*>& toFill);
 
 
         /// @brief Destructor
@@ -337,10 +362,10 @@ protected:
 
     private:
         /// @brief The previously parsed nodes
-        const std::map<SUMOLong, NIOSMNode*>& myOSMNodes;
+        const std::map<long long int, NIOSMNode*>& myOSMNodes;
 
         /// @brief A map of built edges
-        std::map<SUMOLong, Edge*>& myEdgeMap;
+        std::map<long long int, Edge*>& myEdgeMap;
 
         /// @brief The currently built edge
         Edge* myCurrentEdge;
@@ -372,8 +397,8 @@ protected:
          * @param[in] osmNodes The previously parsed OSM-nodes
          * @param[in] osmEdges The previously parse OSM-edges
          */
-        RelationHandler(const std::map<SUMOLong, NIOSMNode*>& osmNodes,
-                        const std::map<SUMOLong, Edge*>& osmEdges);
+        RelationHandler(const std::map<long long int, NIOSMNode*>& osmNodes,
+                        const std::map<long long int, Edge*>& osmEdges);
 
 
         /// @brief Destructor
@@ -406,13 +431,13 @@ protected:
 
     private:
         /// @brief The previously parsed nodes
-        const std::map<SUMOLong, NIOSMNode*>& myOSMNodes;
+        const std::map<long long int, NIOSMNode*>& myOSMNodes;
 
         /// @brief The previously parsed edges
-        const std::map<SUMOLong, Edge*>& myOSMEdges;
+        const std::map<long long int, Edge*>& myOSMEdges;
 
         /// @brief The currently parsed relation
-        SUMOLong myCurrentRelation;
+        long long int myCurrentRelation;
 
         /// @brief The element stack
         std::vector<int> myParentElements;
@@ -421,14 +446,14 @@ protected:
         bool myIsRestriction;
 
         /// @brief the origination way for the current restriction
-        SUMOLong myFromWay;
+        long long int myFromWay;
 
         /// @brief the destination way for the current restriction
-        SUMOLong myToWay;
+        long long int myToWay;
 
         /// @brief the via node/way for the current restriction
-        SUMOLong myViaNode;
-        SUMOLong myViaWay;
+        long long int myViaNode;
+        long long int myViaWay;
 
 
         /** @enum RestrictionType
@@ -448,13 +473,13 @@ protected:
         void resetValues();
 
         /// @brief check whether a referenced way has a corresponding edge
-        bool checkEdgeRef(SUMOLong ref) const;
+        bool checkEdgeRef(long long int ref) const;
 
         /// @brief try to apply the parsed restriction and return whether successful
         bool applyRestriction() const;
 
         /// @brief try to find the way segment among candidates
-        NBEdge* findEdgeRef(SUMOLong wayRef, const std::vector<NBEdge*>& candidates) const;
+        NBEdge* findEdgeRef(long long int wayRef, const std::vector<NBEdge*>& candidates) const;
 
     private:
         /** @brief invalidated copy constructor */
