@@ -5,7 +5,7 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Jul 2006
-/// @version $Id: NINavTeqHelper.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NINavTeqHelper.cpp 21182 2016-07-18 06:46:01Z behrisch $
 ///
 // Some parser methods shared around several formats containing NavTeq-Nets
 /****************************************************************************/
@@ -77,7 +77,7 @@ NINavTeqHelper::getSpeed(const std::string& id, const std::string& speedClassS)
 }
 
 
-unsigned int
+int
 NINavTeqHelper::getLaneNumber(const std::string& id, const std::string& laneNoS, SUMOReal speed) {
     try {
         int nolanes = TplConvert::_2int(laneNoS.c_str());
