@@ -5,12 +5,12 @@
 /// @author  Christian Roessel
 /// @author  Michael Behrisch
 /// @date    Mon, 15 Apr 2002
-/// @version $Id: NLDetectorBuilder.h 18213 2015-04-16 11:55:42Z behrisch $
+/// @version $Id: NLDetectorBuilder.h 20433 2016-04-13 08:00:14Z behrisch $
 ///
 // Builds detectors for microsim
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -34,10 +34,9 @@
 #endif
 
 #include <string>
-#include <microsim/MSNet.h>
+#include <microsim/output/MSCrossSection.h>
 #include <microsim/traffic_lights/MSTLLogicControl.h>
-#include <microsim/output/MSE3Collector.h>
-
+#include <microsim/output/MSE2Collector.h>
 
 // ===========================================================================
 // class declarations
@@ -46,10 +45,8 @@ class MSDetectorFileOutput;
 class MSLane;
 class MSEdge;
 
-#ifdef HAVE_INTERNAL
 class MEInductLoop;
 class MESegment;
-#endif
 
 
 // ===========================================================================
@@ -337,9 +334,10 @@ public:
      * @param[in] lane The lane the detector is placed at
      * @param[in] pos The position on the lane the detector is placed at
      * @param[in] splitByType Whether additional information split by vehicle classes shall be generated
+     * @param[in] show Whether to show the detector in the gui if available
      */
     virtual MSDetectorFileOutput* createInductLoop(const std::string& id,
-            MSLane* lane, SUMOReal pos, bool splitByType);
+            MSLane* lane, SUMOReal pos, bool splitByType, bool show = true);
 
 
     /** @brief Creates an instance of an e1 detector using the given values
@@ -354,21 +352,6 @@ public:
     virtual MSDetectorFileOutput* createInstantInductLoop(const std::string& id,
             MSLane* lane, SUMOReal pos, const std::string& od);
 
-#ifdef HAVE_INTERNAL
-    /** @brief Creates an instance of a mesoscopic e1 detector using the given values
-     *
-     * Simply calls the MEInductLoop constructor
-     *
-     * @param[in] id The id the detector shall have
-     * @param[in] s The segment the detector is placed at
-     * @param[in] pos ?
-     * @todo Position is not used, herein!?
-     */
-    virtual MEInductLoop* createMEInductLoop(const std::string& id,
-            MESegment* s, SUMOReal pos);
-#endif
-
-
     /** @brief Creates an instance of an e2 detector using the given values
      *
      * Simply calls the MSE2Collector constructor
@@ -381,7 +364,7 @@ public:
      * @param[in] haltingSpeedThreshold Detector parameter: the speed a vehicle's speed must be below to be assigned as jammed
      * @param[in] jamDistThreshold Detector parameter: the distance between two vehicles in order to not count them to one jam
      */
-    virtual MSDetectorFileOutput* createSingleLaneE2Detector(const std::string& id,
+    virtual MSE2Collector* createSingleLaneE2Detector(const std::string& id,
             DetectorUsage usage, MSLane* lane, SUMOReal pos, SUMOReal length,
             SUMOTime haltingTimeThreshold,
             SUMOReal haltingSpeedThreshold,
@@ -462,10 +445,10 @@ public:
      * @param[in] jamDistThreshold Detector parameter: the distance between two vehicles in order to not count them to one jam
      * @todo Check whether this method is really needful
      */
-    MSDetectorFileOutput* buildSingleLaneE2Det(const std::string& id,
-            DetectorUsage usage, MSLane* lane, SUMOReal pos, SUMOReal length,
-            SUMOTime haltingTimeThreshold, SUMOReal haltingSpeedThreshold,
-            SUMOReal jamDistThreshold);
+    MSE2Collector* buildSingleLaneE2Det(const std::string& id,
+                                        DetectorUsage usage, MSLane* lane, SUMOReal pos, SUMOReal length,
+                                        SUMOTime haltingTimeThreshold, SUMOReal haltingSpeedThreshold,
+                                        SUMOReal jamDistThreshold);
 
 
     /** @brief Builds an e2 detector that continues on preceeding lanes
