@@ -5,7 +5,7 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: RORouteHandler.cpp 21078 2016-07-01 09:23:25Z behrisch $
+/// @version $Id: RORouteHandler.cpp 21236 2016-07-25 14:24:30Z namdre $
 ///
 // Parser and container for routes during their loading
 /****************************************************************************/
@@ -109,9 +109,13 @@ RORouteHandler::parseFromViaTo(std::string element,
     if (!attrs.hasAttribute(SUMO_ATTR_VIA)) {
         myInsertStopEdgesAt = (int)myActiveRoute.size();
     }
+    ConstROEdgeVector viaEdges;
     parseEdges(attrs.getOpt<std::string>(SUMO_ATTR_VIA, myVehicleParameter->id.c_str(), ok, "", true),
-               myActiveRoute, "for " + element + " '" + myVehicleParameter->id + "'");
-    myVehicleParameter->via = StringTokenizer(attrs.getOpt<std::string>(SUMO_ATTR_VIA, myVehicleParameter->id.c_str(), ok, "", true)).getVector();
+               viaEdges, "for " + element + " '" + myVehicleParameter->id + "'");
+    for (ConstROEdgeVector::const_iterator i = viaEdges.begin(); i != viaEdges.end(); ++i) {
+        myActiveRoute.push_back(*i);
+        myVehicleParameter->via.push_back((*i)->getID());
+    }
 
     if ((useTaz || !attrs.hasAttribute(SUMO_ATTR_TO)) && myVehicleParameter->wasSet(VEHPARS_TO_TAZ_SET)) {
         const ROEdge* toTaz = myNet.getEdge(myVehicleParameter->toTaz + "-sink");
