@@ -2,7 +2,7 @@
 /// @file    TraCIServerAPI_Person.cpp
 /// @author  Daniel Krajzewicz
 /// @date    26.05.2014
-/// @version $Id: TraCIServerAPI_Person.cpp 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: TraCIServerAPI_Person.cpp 20768 2016-05-20 08:38:44Z behrisch $
 ///
 // APIs for getting/setting person values via TraCI
 /****************************************************************************/
@@ -30,7 +30,7 @@
 
 #ifndef NO_TRACI
 
-#include <microsim/MSPersonControl.h>
+#include <microsim/MSTransportableControl.h>
 #include <microsim/pedestrians/MSPerson.h>
 #include <microsim/MSNet.h>
 #include <microsim/MSEdge.h>
@@ -70,12 +70,14 @@ TraCIServerAPI_Person::processGet(TraCIServer& server, tcpip::Storage& inputStor
     tempMsg.writeUnsignedByte(RESPONSE_GET_PERSON_VARIABLE);
     tempMsg.writeUnsignedByte(variable);
     tempMsg.writeString(id);
-    MSPersonControl& c = MSNet::getInstance()->getPersonControl();
+    MSTransportableControl& c = MSNet::getInstance()->getPersonControl();
     if (variable == ID_LIST || variable == ID_COUNT) {
         if (variable == ID_LIST) {
             std::vector<std::string> ids;
-            for (MSPersonControl::constVehIt i = c.loadedPersonsBegin(); i != c.loadedPersonsEnd(); ++i) {
-                ids.push_back((*i).first);
+            for (MSTransportableControl::constVehIt i = c.loadedBegin(); i != c.loadedEnd(); ++i) {
+                if (i->second->getCurrentStageType() != MSTransportable::WAITING_FOR_DEPART) {
+                    ids.push_back(i->first);
+                }
             }
             tempMsg.writeUnsignedByte(TYPE_STRINGLIST);
             tempMsg.writeStringList(ids);
@@ -166,7 +168,7 @@ TraCIServerAPI_Person::processSet(TraCIServer& server, tcpip::Storage& inputStor
         return server.writeErrorStatusCmd(CMD_SET_PERSON_VARIABLE, "Change Person State: unsupported variable " + toHex(variable, 2) + " specified", outputStorage);
     }
     // id
-    MSPersonControl& c = MSNet::getInstance()->getPersonControl();
+    MSTransportableControl& c = MSNet::getInstance()->getPersonControl();
     std::string id = inputStorage.readString();
     MSTransportable* p = c.get(id);
     if (p == 0) {
