@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2006
-/// @version $Id: GUITexturesHelper.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: GUITexturesHelper.h 21182 2016-07-18 06:46:01Z behrisch $
 ///
 // Global storage for textures; manages and draws them
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2006-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2006-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -52,25 +52,25 @@ public:
     static GUIGlID add(FXImage* i);
 
     /// Draws a named texture as a box with the given size
-    static void drawTexturedBox(unsigned int which, SUMOReal size);
+    static void drawTexturedBox(int which, SUMOReal size);
 
     /// Draws a named texture as a rectangle with the given sizes
-    static void drawTexturedBox(unsigned int which,
+    static void drawTexturedBox(int which,
                                 SUMOReal sizeX1, SUMOReal sizeY1, SUMOReal sizeX2, SUMOReal sizeY2);
 
     /// @brief return texture id for the given filename (initialize on first use)
     // @note return -1 on failure
-    static int getTextureID(const std::string& filename);
+    static int getTextureID(const std::string& filename, const bool mirrorX = false);
 
     /// @brief clears loaded textures
     static void clearTextures();
 
-    /// @brief don't draw any textures
+    /// @brief switch texture drawing on and off
     static void allowTextures(const bool val) {
         myAllowTextures = val;
     }
 
-    /// @brief clears loaded textures
+    /// @brief ask whether texture drawing is enabled
     static bool texturesAllowed() {
         return myAllowTextures;
     }
