@@ -4,7 +4,7 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIDanielPerspectiveChanger.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GUIDanielPerspectiveChanger.cpp 21186 2016-07-18 12:04:16Z namdre $
 ///
 // A class that allows to steer the visual output in dependence to
 /****************************************************************************/
@@ -119,6 +119,24 @@ GUIDanielPerspectiveChanger::getZoom() const {
 }
 
 
+SUMOReal
+GUIDanielPerspectiveChanger::getZPos() const {
+    return myViewPort.getWidth();
+}
+
+
+SUMOReal
+GUIDanielPerspectiveChanger::zoom2ZPos(SUMOReal zoom) const {
+    return myOrigWidth / (zoom / 100);
+}
+
+
+SUMOReal
+GUIDanielPerspectiveChanger::zPos2Zoom(SUMOReal zPos) const {
+    return (myOrigWidth / zPos) * 100;
+}
+
+
 void
 GUIDanielPerspectiveChanger::centerTo(const Position& pos, SUMOReal radius,
                                       bool applyZoom) {
@@ -244,6 +262,12 @@ GUIDanielPerspectiveChanger::setViewport(SUMOReal zoom,
 }
 
 
+void 
+GUIDanielPerspectiveChanger::setViewportFrom(SUMOReal xPos, SUMOReal yPos, SUMOReal zPos) {
+    setViewport(zPos2Zoom(zPos), xPos, yPos);
+}
+
+
 void
 GUIDanielPerspectiveChanger::changeCanvassLeft(int change) {
     myViewPort = Boundary(
