@@ -4,7 +4,7 @@
 /// @author  Mario Krumnow
 /// @author  Michael Behrisch
 /// @date    30.05.2012
-/// @version $Id: TraCIAPI.h 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: TraCIAPI.h 21182 2016-07-18 06:46:01Z behrisch $
 ///
 // C++ TraCI client API implementation
 /****************************************************************************/
@@ -112,14 +112,14 @@ public:
 
     class TraCILogic {
     public:
-        TraCILogic(const std::string& _subID, int _type, const std::map<std::string, SUMOReal>& _subParameter, unsigned int _currentPhaseIndex, const std::vector<TraCIPhase>& _phases)
+        TraCILogic(const std::string& _subID, int _type, const std::map<std::string, SUMOReal>& _subParameter, int _currentPhaseIndex, const std::vector<TraCIPhase>& _phases)
             : subID(_subID), type(_type), subParameter(_subParameter), currentPhaseIndex(_currentPhaseIndex), phases(_phases) {}
         ~TraCILogic() {}
 
         std::string subID;
         int type;
         std::map<std::string, SUMOReal> subParameter;
-        unsigned int currentPhaseIndex;
+        int currentPhaseIndex;
         std::vector<TraCIPhase> phases;
     };
 
@@ -228,7 +228,7 @@ public:
         virtual ~EdgeScope() {}
 
         std::vector<std::string> getIDList() const;
-        unsigned int getIDCount() const;
+        int getIDCount() const;
         SUMOReal getAdaptedTraveltime(const std::string& edgeID, SUMOTime time) const;
         SUMOReal getEffort(const std::string& edgeID, SUMOTime time) const;
         SUMOReal getCO2Emission(const std::string& edgeID) const;
@@ -243,7 +243,7 @@ public:
         SUMOReal getLastStepOccupancy(const std::string& edgeID) const;
         SUMOReal getLastStepLength(const std::string& edgeID) const;
         SUMOReal getTraveltime(const std::string& edgeID) const;
-        unsigned int getLastStepVehicleNumber(const std::string& edgeID) const;
+        int getLastStepVehicleNumber(const std::string& edgeID) const;
         SUMOReal getLastStepHaltingNumber(const std::string& edgeID) const;
         std::vector<std::string> getLastStepVehicleIDs(const std::string& edgeID) const;
 
@@ -324,7 +324,7 @@ public:
         std::vector<std::string> getIDList() const;
         SUMOReal  getPosition(const std::string& loopID) const;
         std::string getLaneID(const std::string& loopID) const;
-        unsigned int getLastStepVehicleNumber(const std::string& loopID) const;
+        int getLastStepVehicleNumber(const std::string& loopID) const;
         SUMOReal getLastStepMeanSpeed(const std::string& loopID) const;
         std::vector<std::string> getLastStepVehicleIDs(const std::string& loopID) const;
         SUMOReal getLastStepOccupancy(const std::string& loopID) const;
@@ -384,7 +384,7 @@ public:
         SUMOReal getWidth(const std::string& laneID) const;
         std::vector<std::string> getAllowed(const std::string& laneID) const;
         std::vector<std::string> getDisallowed(const std::string& laneID) const;
-        unsigned int getLinkNumber(const std::string& laneID) const;
+        int getLinkNumber(const std::string& laneID) const;
         TraCIPositionVector getShape(const std::string& laneID) const;
         std::string getEdgeID(const std::string& laneID) const;
         SUMOReal getCO2Emission(const std::string& laneID) const;
@@ -399,8 +399,8 @@ public:
         SUMOReal getLastStepOccupancy(const std::string& laneID) const;
         SUMOReal getLastStepLength(const std::string& laneID) const;
         SUMOReal getTraveltime(const std::string& laneID) const;
-        unsigned int getLastStepVehicleNumber(const std::string& laneID) const;
-        unsigned int getLastStepHaltingNumber(const std::string& laneID) const;
+        int getLastStepVehicleNumber(const std::string& laneID) const;
+        int getLastStepHaltingNumber(const std::string& laneID) const;
         std::vector<std::string> getLastStepVehicleIDs(const std::string& laneID) const;
 
         void setAllowed(const std::string& laneID, const std::vector<std::string>& allowedClasses) const;
@@ -449,10 +449,10 @@ public:
         virtual ~MeMeScope() {}
 
         std::vector<std::string> getIDList() const;
-        unsigned int getLastStepVehicleNumber(const std::string& detID) const;
+        int getLastStepVehicleNumber(const std::string& detID) const;
         SUMOReal getLastStepMeanSpeed(const std::string& detID) const;
         std::vector<std::string> getLastStepVehicleIDs(const std::string& detID) const;
-        unsigned int getLastStepHaltingNumber(const std::string& detID) const;
+        int getLastStepHaltingNumber(const std::string& detID) const;
 
     private:
         /// @brief invalidated copy constructor
@@ -569,19 +569,19 @@ public:
         virtual ~SimulationScope() {}
 
         SUMOTime getCurrentTime() const;
-        unsigned int getLoadedNumber() const;
+        int getLoadedNumber() const;
         std::vector<std::string> getLoadedIDList() const;
-        unsigned int getDepartedNumber() const;
+        int getDepartedNumber() const;
         std::vector<std::string> getDepartedIDList() const;
-        unsigned int getArrivedNumber() const;
+        int getArrivedNumber() const;
         std::vector<std::string> getArrivedIDList() const;
-        unsigned int getStartingTeleportNumber() const;
+        int getStartingTeleportNumber() const;
         std::vector<std::string> getStartingTeleportIDList() const;
-        unsigned int getEndingTeleportNumber() const;
+        int getEndingTeleportNumber() const;
         std::vector<std::string> getEndingTeleportIDList() const;
         SUMOTime getDeltaT() const;
         TraCIBoundary getNetBoundary() const;
-        unsigned int getMinExpectedNumber() const;
+        int getMinExpectedNumber() const;
 
         void subscribe(int domID, const std::string& objID, SUMOTime beginTime, SUMOTime endTime, const std::vector<int>& vars) const;
         void subscribeContext(int domID, const std::string& objID, SUMOTime beginTime, SUMOTime endTime, int domain, SUMOReal range, const std::vector<int>& vars) const;
@@ -619,13 +619,13 @@ public:
         std::vector<std::string> getControlledLanes(const std::string& tlsID) const;
         std::vector<TraCIAPI::TraCILink> getControlledLinks(const std::string& tlsID) const;
         std::string getProgram(const std::string& tlsID) const;
-        unsigned int getPhase(const std::string& tlsID) const;
-        unsigned int getNextSwitch(const std::string& tlsID) const;
+        int getPhase(const std::string& tlsID) const;
+        int getNextSwitch(const std::string& tlsID) const;
 
         void setRedYellowGreenState(const std::string& tlsID, const std::string& state) const;
-        void setPhase(const std::string& tlsID, unsigned int index) const;
+        void setPhase(const std::string& tlsID, int index) const;
         void setProgram(const std::string& tlsID, const std::string& programID) const;
-        void setPhaseDuration(const std::string& tlsID, unsigned int phaseDuration) const;
+        void setPhaseDuration(const std::string& tlsID, int phaseDuration) const;
         void setCompleteRedYellowGreenDefinition(const std::string& tlsID, const TraCIAPI::TraCILogic& logic) const;
 
     private:
@@ -717,16 +717,16 @@ public:
 
 
         std::vector<std::string> getIDList() const;
-        unsigned int getIDCount() const;
+        int getIDCount() const;
         SUMOReal getSpeed(const std::string& vehicleID) const;
         TraCIPosition getPosition(const std::string& vehicleID) const;
         SUMOReal getAngle(const std::string& vehicleID) const;
         std::string getRoadID(const std::string& vehicleID) const;
         std::string getLaneID(const std::string& vehicleID) const;
-        unsigned int getLaneIndex(const std::string& vehicleID) const;
+        int getLaneIndex(const std::string& vehicleID) const;
         std::string getTypeID(const std::string& vehicleID) const;
         std::string getRouteID(const std::string& vehicleID) const;
-        unsigned int getRouteIndex(const std::string& vehicleID) const;
+        int getRouteIndex(const std::string& vehicleID) const;
         std::vector<std::string> getEdges(const std::string& vehicleID) const;
         TraCIColor getColor(const std::string& vehicleID) const;
         SUMOReal getLanePosition(const std::string& vehicleID) const;
@@ -738,7 +738,7 @@ public:
         SUMOReal getFuelConsumption(const std::string& vehicleID) const;
         SUMOReal getNoiseEmission(const std::string& vehicleID) const;
         SUMOReal getElectricityConsumption(const std::string& vehicleID) const;
-        unsigned int getSignalStates(const std::string& vehicleID) const;
+        int getSignalStates(const std::string& vehicleID) const;
         SUMOReal getWaitingTime(const std::string& vehicleID) const;
         std::vector<NextTLSData> getNextTLS(const std::string& vehID) const;
         int getSpeedMode(const std::string& vehicleID) const;
@@ -752,8 +752,8 @@ public:
         SUMOReal getNOxEmissions(const std::string& vehicleID) const;
         SUMOReal getFuelConsumption(const std::string& vehicleID) const;
         SUMOReal getNoiseEmission(const std::string& vehicleID) const;
-        unsigned int getBestLanes(const std::string& vehicleID) const;
-        unsigned int getStopState(const std::string& vehicleID) const;
+        int getBestLanes(const std::string& vehicleID) const;
+        int getStopState(const std::string& vehicleID) const;
         SUMOReal getLength(const std::string& vehicleID) const;
         SUMOReal getMaxSpeed(const std::string& vehicleID) const;
         SUMOReal getAccel(const std::string& vehicleID) const;
@@ -809,7 +809,7 @@ public:
         virtual ~PersonScope() {}
 
         std::vector<std::string> getIDList() const;
-        unsigned int getIDCount() const;
+        int getIDCount() const;
         SUMOReal getSpeed(const std::string& typeID) const;
         TraCIPosition getPosition(const std::string& typeID) const;
         std::string getRoadID(const std::string& typeID) const;
