@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Mon, 1 Jul 2002
-/// @version $Id: XMLSubSys.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: XMLSubSys.h 21182 2016-07-18 06:46:01Z behrisch $
 ///
 // Utility methods for initialising, closing and using the XML-subsystem
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -153,7 +153,7 @@ private:
     static std::vector<SUMOSAXReader*> myReaders;
 
     /// @brief Information whether the reader is parsing
-    static unsigned int myNextFreeReader;
+    static int myNextFreeReader;
 
     /// @brief Information whether built reader/parser shall validate XML-documents against schemata
     static XERCES_CPP_NAMESPACE::SAX2XMLReader::ValSchemes myValidationScheme;
