@@ -101,9 +101,7 @@ public class Vehicle {
 		Object[] array = new Object[]{dist};
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_LEADER, vehID, array, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_COMPOUND);
 	}
-	
-	
-	
+
 	
 	/**
 	 * getPersonNumber
@@ -322,6 +320,18 @@ public class Vehicle {
 	public static SumoCommand getMinGap(String vehID){
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_MINGAP, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
 	}
+	
+	
+	/**
+	 * Return list of upcoming traffic lights [(tlsID, tlsIndex, distance, state), ...]
+	 * @param vehID id of the vehicle
+	 * @return
+	 */
+	public static SumoCommand getNextTLS(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_NEXT_TLS, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_COMPOUND);
+	}
+	
+	
 
 	/**
 	 * Returns the NOx emissions (in mg) generated by the vehicle during the last time step.
@@ -687,6 +697,31 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_MOVE_TO_VTD, vehID, array);
 	}
 
+	/**
+	 * Place vehicle at the given x,y coordinates and force it's angle to
+        the given value (for drawing). If keepRoute is set to 1, the closest position
+        within the existing route is taken. If keepRoute is set to 0, the vehicle may move to
+        any edge in the network but it's route then only consists of that edge.
+        If keepRoute is set to 2 the vehicle has all the freedom of keepRoute=1
+        but in addition to that may even move outside the road network.
+        edgeID and lane are optional placement hints to resolve ambiguities
+
+	 * @param vehID vehicle id
+	 * @param edgeID edge id
+	 * @param lane lane
+	 * @param x x
+	 * @param y y
+	 * @param angle angle
+	 * @param  keepRoute keepRoute 
+	 * @return SumoCommand
+	 */
+	public static SumoCommand moveToXY(String vehID, String edgeID, int lane, double x, double y, double angle, byte keepRoute){
+
+		Object[] array = new Object[]{edgeID, lane, x, y, angle, keepRoute};
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_MOVE_TO_VTD, vehID, array);
+	}
+	
+	
 	/**
 	 * Removes vehicle with the given ID for the given reason. Reasons are defined in module constants and start with REMOVE_
 
@@ -895,7 +930,7 @@ public class Vehicle {
 	 * @param signals signals
 	 * @return SumoCommand
 	 */
-	public static SumoCommand setSignals(String vehID, String signals){
+	public static SumoCommand setSignals(String vehID, int signals){
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_SIGNALS, vehID, signals);
 	}
 
