@@ -4,13 +4,13 @@
 @author  Daniel Krajzewicz
 @author  Michael Behrisch
 @date    2008-07-17
-@version $Id: CSV2polyconvertXML.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: CSV2polyconvertXML.py 20482 2016-04-18 20:49:42Z behrisch $
 
 Converts a given CSV-file that contains a list of pois to 
  an XML-file that may be read by POLYCONVERT.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2008-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2008-2016 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -18,14 +18,18 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 
 import sys
 
-if len(sys.argv)<4:
-    print "Error: Missing argument(s)"
-    print "Call: CSV2polyconvertXML.py <CSV_FILE> <OUTPUT_FILE> <VALUENAME>[,<VALUENAME>]*"
-    print " The values within the csv-file are supposed to be divided by ';'."
-    print " <VALUENAME>s give the attribute names in order of their appearence within the csv-file ."
+if len(sys.argv) < 4:
+    print("Error: Missing argument(s)")
+    print(
+        "Call: CSV2polyconvertXML.py <CSV_FILE> <OUTPUT_FILE> <VALUENAME>[,<VALUENAME>]*")
+    print(" The values within the csv-file are supposed to be divided by ';'.")
+    print(
+        " <VALUENAME>s give the attribute names in order of their appearence within the csv-file .")
     exit()
 
 
@@ -34,12 +38,12 @@ inpf = open(sys.argv[1])
 outf = open(sys.argv[2], "w")
 outf.write("<pois>\n")
 for line in inpf:
-    if len(line)==0 or line[0]=='#':
+    if len(line) == 0 or line[0] == '#':
         continue
     vals = line.strip().split(';')
     outf.write("    <poi")
-    for i,n in enumerate(names):
-         outf.write(' ' + n + '="' + vals[i] + '"')
+    for i, n in enumerate(names):
+        outf.write(' ' + n + '="' + vals[i] + '"')
     outf.write("/>\n")
 outf.write("</pois>\n")
 inpf.close()
