@@ -3,12 +3,12 @@
 @author  Jakob Erdmann
 @author  Michael Behrisch
 @date    2012-05-08
-@version $Id: miscutils.py 18096 2015-03-17 09:50:59Z behrisch $
+@version $Id: miscutils.py 20482 2016-04-18 20:49:42Z behrisch $
 
 Common utility functions
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2012-2015 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2012-2016 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -16,6 +16,8 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 import sys
 import time
 import os
@@ -34,22 +36,34 @@ from collections import defaultdict
 
 class _ExtremeType(object):
 
-    def __init__(self, cmpr, rep):
+    def __init__(self, isMax, rep):
         object.__init__(self)
-        self._cmpr = cmpr
+        self._isMax = isMax
         self._rep = rep
 
-    def __cmp__(self, other):
-        if isinstance(other, self.__class__) and\
-           other._cmpr == self._cmpr:
-            return 0
-        return self._cmpr
+    def __eq__(self, other):
+        return isinstance(other, self.__class__) and other._isMax == self._isMax
+
+    def __ne__(self, other):
+        return not self == other
+
+    def __gt__(self, other):
+        return self._isMax and not self == other
+
+    def __ge__(self, other):
+        return self._isMax
+
+    def __lt__(self, other):
+        return not self._isMax and not self == other
+
+    def __le__(self, other):
+        return not self._isMax
 
     def __repr__(self):
         return self._rep
 
-uMax = _ExtremeType(1, "uMax")
-uMin = _ExtremeType(-1, "uMin")
+uMax = _ExtremeType(True, "uMax")
+uMin = _ExtremeType(False, "uMin")
 
 # decorator for timing a function
 
@@ -128,8 +142,8 @@ class Statistics:
         else:
             return None
 
-    def relStdDev(self, limit=None):
-        """return the relative standard deviation optionally limited to the last limit values"""
+    def meanAndStdDev(self, limit=None):
+        """return the mean and the standard deviation optionally limited to the last limit values"""
         if limit is None or len(self.values) < limit:
             limit = len(self.values)
         if limit > 0:
@@ -137,10 +151,17 @@ class Statistics:
             sumSq = 0.
             for v in self.values[-limit:]:
                 sumSq += (v - mean) * (v - mean)
-            return math.sqrt(sumSq / limit) / mean
+            return mean, math.sqrt(sumSq / limit)
         else:
             return None
 
+    def relStdDev(self, limit=None):
+        """return the relative standard deviation optionally limited to the last limit values"""
+        moments = self.meanAndStdDev(limit)
+        if moments is None:
+            return None
+        return moments[1] / moments[0]
+
     def mean(self):
         """return the median value"""
         # XXX rename this method
@@ -172,7 +193,7 @@ class Statistics:
 
     def quartiles(self):
         s = sorted(self.values)
-        return s[len(self.values) / 4], s[len(self.values) / 2], s[3 * len(self.values) / 4]
+        return s[len(self.values) // 4], s[len(self.values) // 2], s[3 * len(self.values) // 4]
 
     def rank(self, fraction):
         if len(self.values) > 0:
@@ -203,7 +224,7 @@ class Statistics:
                 result += '\n histogram: %s' % self.histogram()
             return result
         else:
-            return '"%s": no values' % self.label
+            return '%s: no values' % self.label
 
 
 def geh(m, c):
