@@ -6,7 +6,7 @@
 @author  Michael Behrisch
 @author  Jakob Erdmann
 @date    2008-03-27
-@version $Id: __init__.py 20482 2016-04-18 20:49:42Z behrisch $
+@version $Id: __init__.py 21064 2016-06-29 12:10:35Z namdre $
 
 This file contains a content handler for parsing sumo network xml files.
 It uses other classes from this module to represent the road network.
@@ -26,6 +26,7 @@ from __future__ import absolute_import
 import os
 import sys
 import math
+import re
 from xml.sax import saxutils, parse, handler
 from copy import copy
 from itertools import *
@@ -138,17 +139,18 @@ class Net:
         self._location["origBoundary"] = origBoundary
         self._location["projParameter"] = projParameter
 
-    def addNode(self, id, type=None, coord=None, incLanes=None):
+    def addNode(self, id, type=None, coord=None, incLanes=None, intLanes=None):
         if id is None:
             return None
         if id not in self._id2node:
-            n = node.Node(id, type, coord, incLanes)
+            n = node.Node(id, type, coord, incLanes, intLanes)
             self._nodes.append(n)
             self._id2node[id] = n
-        self.setAdditionalNodeInfo(self._id2node[id], type, coord, incLanes)
+        self.setAdditionalNodeInfo(
+            self._id2node[id], type, coord, incLanes, intLanes)
         return self._id2node[id]
 
-    def setAdditionalNodeInfo(self, node, type, coord, incLanes):
+    def setAdditionalNodeInfo(self, node, type, coord, incLanes, intLanes=None):
         if coord != None and node._coord == None:
             node._coord = coord
             self._ranges[0][0] = min(self._ranges[0][0], coord[0])
@@ -157,6 +159,8 @@ class Net:
             self._ranges[1][1] = max(self._ranges[1][1], coord[1])
         if incLanes != None and node._incLanes == None:
             node._incLanes = incLanes
+        if intLanes != None and node._intLanes == None:
+            node._intLanes = intLanes
         if type != None and node._type == None:
             node._type = type
 
@@ -172,14 +176,14 @@ class Net:
     def addLane(self, edge, speed, length, allow=None, disallow=None):
         return lane.Lane(edge, speed, length, allow, disallow)
 
-    def addRoundabout(self, nodes):
-        r = roundabout.Roundabout(nodes)
+    def addRoundabout(self, nodes, edges=None):
+        r = roundabout.Roundabout(nodes, edges)
         self._roundabouts.append(r)
         return r
 
-    def addConnection(self, fromEdge, toEdge, fromlane, tolane, direction, tls, tllink, state):
+    def addConnection(self, fromEdge, toEdge, fromlane, tolane, direction, tls, tllink, state, viaLaneID=None):
         conn = connection.Connection(
-            fromEdge, toEdge, fromlane, tolane, direction, tls, tllink, state)
+            fromEdge, toEdge, fromlane, tolane, direction, tls, tllink, state, viaLaneID)
         fromEdge.addOutgoing(conn)
         fromlane.addOutgoing(conn)
         toEdge._addIncoming(conn)
@@ -196,6 +200,10 @@ class Net:
     def getEdge(self, id):
         return self._id2edge[id]
 
+    def getLane(self, laneID):
+        edge_id, lane_index = laneID.rsplit("_", 1)
+        return self.getEdge(edge_id).getLane(int(lane_index))
+
     def _initRTree(self, shapeList, includeJunctions=True):
         import rtree
         self._rtree = rtree.index.Index()
@@ -422,8 +430,11 @@ class NetReader(handler.ContentHandler):
                 self._currentShape = ""
         if name == 'junction':
             if attrs['id'][0] != ':':
+                intLanes = None
+                if self._withInternal:
+                    intLanes = attrs["intLanes"].split(" ")
                 self._currentNode = self._net.addNode(attrs['id'], attrs['type'], (float(
-                    attrs['x']), float(attrs['y'])), attrs['incLanes'].split(" "))
+                    attrs['x']), float(attrs['y'])), attrs['incLanes'].split(" "), intLanes)
         if name == 'succ' and self._withConnections:  # deprecated
             if attrs['edge'][0] != ':':
                 self._currentEdge = self._net.getEdge(attrs['edge'])
@@ -451,10 +462,11 @@ class NetReader(handler.ContentHandler):
                     tllink = -1
                 toEdge = self._net.getEdge(lid[:lid.rfind('_')])
                 tolane = toEdge._lanes[tolane]
+                viaLaneID = attrs['via']
                 self._net.addConnection(self._currentEdge, connected, self._currentEdge._lanes[
                                         self._currentLane], tolane,
-                                        attrs['dir'], tl, tllink, attrs['state'])
-        if name == 'connection' and self._withConnections and attrs['from'][0] != ":":
+                                        attrs['dir'], tl, tllink, attrs['state'], viaLaneID)
+        if name == 'connection' and self._withConnections and (attrs['from'][0] != ":" or self._withInternal):
             fromEdgeID = attrs['from']
             toEdgeID = attrs['to']
             if not (fromEdgeID in self._net._crossings_and_walkingAreas or toEdgeID in
@@ -471,9 +483,15 @@ class NetReader(handler.ContentHandler):
                 else:
                     tl = ""
                     tllink = -1
+                try:
+                    viaLaneID = attrs['via']
+                except KeyError:
+                    viaLaneID = ''
+
                 self._net.addConnection(
                     fromEdge, toEdge, fromLane, toLane, attrs['dir'], tl,
-                    tllink, attrs['state'])
+                    tllink, attrs['state'], viaLaneID)
+
         # 'row-logic' is deprecated!!!
         if self._withFoes and name == 'ROWLogic':
             self._currentNode = attrs['id']
@@ -483,14 +501,17 @@ class NetReader(handler.ContentHandler):
         if name == 'request' and self._withFoes:
             self._currentNode.setFoes(
                 int(attrs['index']), attrs["foes"], attrs["response"])
-        if self._withPhases and name == 'tlLogic':  # tl-logic is deprecated!!!
+        # tl-logic is deprecated!!! NOTE: nevertheless, this is still used by
+        # netconvert... (Leo)
+        if self._withPhases and name == 'tlLogic':
             self._currentProgram = self._net.addTLSProgram(
                 attrs['id'], attrs['programID'], int(attrs['offset']), attrs['type'])
         if self._withPhases and name == 'phase':
             self._currentProgram.addPhase(
                 attrs['state'], int(attrs['duration']))
         if name == 'roundabout':
-            self._net.addRoundabout(attrs['nodes'].split())
+            self._net.addRoundabout(
+                attrs['nodes'].split(), attrs['edges'].split())
         if name == 'param':
             if self._currentLane != None:
                 self._currentLane.setParam(attrs['key'], attrs['value'])
