@@ -6,7 +6,7 @@
 @author  Michael Behrisch
 @author  Jakob Erdmann
 @date    2011-11-28
-@version $Id: lane.py 20433 2016-04-13 08:00:14Z behrisch $
+@version $Id: lane.py 20604 2016-05-02 06:13:40Z behrisch $
 
 This file contains a Python-representation of a single lane.
 
@@ -20,6 +20,8 @@ the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
 
+import sumolib.geomhelper
+
 # taken from sumo/src/utils/common/SUMOVehicleClass.cpp
 SUMO_VEHICLE_CLASSES = (
     "public_emergency",  # deprecated
@@ -122,6 +124,9 @@ class Lane:
         assert(xmin != xmax or ymin != ymax)
         return (xmin, ymin, xmax, ymax)
 
+    def getClosestLanePosAndDist(self, point, perpendicular=False):
+        return sumolib.geomhelper.polygonOffsetAndDistanceToPoint(point, self.getShape(), perpendicular)
+
     def getIndex(self):
         return self._edge._lanes.index(self)
 
